.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER USER" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER USER \- データベースユーザアカウントの変更

.SH SYNOPSIS
.sp
.nf
ALTER USER \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

 ここで \fIoption\fR は以下のとおりです。

    [ ENCRYPTED | UNENCRYPTED ] PASSWORD '\fIpassword\fR' 
    | CREATEDB | NOCREATEDB
    | CREATEUSER | NOCREATEUSER 
    | VALID UNTIL '\fIabstime\fR'

ALTER USER \fIname\fR RENAME TO \fInewname\fR

ALTER USER \fIname\fR SET \fIparameter\fR { TO | = } { \fIvalue\fR | DEFAULT }
ALTER USER \fIname\fR RESET \fIparameter\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER USER\fR を使用すると、PostgreSQL ユーザアカウントの属性を変更できます。
このコマンドで指定されなかった属性は、以前の設定のまま残ります。
.PP
概要で示されているこのコマンドの最初の構文により、特定のグローバルユーザ権限および認証設定が変更されます。 
(詳細は下記を参照してください。)
データベーススーパーユーザのみがこのコマンドで権限とパスワード有効期限を変更することができます。
一般ユーザは自分自身のパスワードのみを変えることができます。
.PP
2番目の構文は、ユーザ名を変更します。
データベーススーパーユーザのみがユーザアカウントの名前を変更できます。
そのセッションのユーザの名前を変更することはできません。
(必要な場合は異なるユーザで接続してください。)
.PP
3 番目および 4 番目の構文により、ユーザのセッションのデフォルト値を、指定した設定変数に変更できます。
このコマンドの後に新しいセッションを開始すると、指定された値がそのセッションのデフォルト値となり、\fIpostgresql.conf\fR ファイルに記述されている設定や、\fBpostmaster\fR から受け取った設定は上書きされます。 
一般ユーザは、自分自身のセッションのデフォルト値を変更できます。 
スーパーユーザは、すべてのユーザのセッションのデフォルト値を変更できます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
属性が変更されるユーザの名前です。
.TP
\fB\fIpassword\fB\fR
このアカウントに使われる新しいパスワードです。
.TP
\fBENCRYPTED\fR
.TP
\fBUNENCRYPTED\fR
これらのキーワードを使用すると、パスワードを暗号化して pg_shadow に格納するかどうかを制御できます。 (このキーワードの選択に関する詳細については、CREATE USER [\fBcreate_user\fR(l)] を参照してください。)
.TP
\fBCREATEDB\fR
.TP
\fBNOCREATEDB\fR
この句はユーザのデータベースの作成に関する権限を定義します。 
CREATEDB が指定された場合、そのユーザは、自分が所有するデータベースを作成できます。 
NOCREATEDB を指定した場合、作成されるユーザにはデータベースを作成する権限が与えられません。
.TP
\fBCREATEUSER\fR
.TP
\fBNOCREATEUSER\fR
この句は、ユーザが自分で新しいユーザを作成できるかどうかを決定します。
またこのオプションにより、そのユーザは全てのアクセス制限を上書きできるスーパーユーザになります。
.TP
\fB\fIabstime\fB\fR
ユーザのパスワードの期限が切れる日付（そしてオプションで時刻）です。
パスワードの有効期限を無効にするには、'infinity'を使用してください。
.TP
\fB\fInewname\fB\fR
ユーザの新しい名前です。
.TP
\fB\fIparameter\fB\fR
.TP
\fB\fIvalue\fB\fR
指定された設定パラメータにおけるこのユーザのセッションのデフォルトを、この値に設定します。 
\fIvalue\fR が DEFAULT であるか、または RESET が使用されている場合、ユーザが指定した変数の設定は無効になり、ユーザは、新しいセッションではシステム全体のデフォルト設定を継承します。 
すべての設定をクリアするには、RESET ALL を使用してください。

使用可能なパラメータ名および値についての詳細は、SET [\fBset\fR(l)] および[XRef to RUNTIME-CONFIG]を参照してください。
.SH "注釈"
.PP
新しいユーザの追加には CREATE USER [\fBcreate_user\fR(l)] を、ユーザの削除には DROP USER [\fBdrop_user\fR(l)] を使用して下さい。
.PP
\fBALTER USER\fR ではユーザグループのメンバ構成を変更することはできません。
そのためには ALTER GROUP [\fBalter_group\fR(l)] を使用して下さい。
.PP
ALTER DATABASE [\fBalter_database\fR(l)] を使用すると、ユーザではなく指定したデータベースにセッションのデフォルト値を関連付けることもできます。
.SH "例"
.PP
ユーザのパスワードを変更します。
.sp
.nf
ALTER USER davide WITH PASSWORD 'hu8jmn3';
.sp
.fi
.PP
ユーザの有効期限を変更します。
.sp
.nf
ALTER USER manuel VALID UNTIL 'Jan 31 2030';
.sp
.fi
.PP
ユーザの権限が UTC から 1 時間進んだタイムゾーンの 2005 年 5 月 4 日の正午に無効になると指定することにより、ユーザの有効期限を変更します。
.sp
.nf
ALTER USER chris VALID UNTIL 'May 4 12:00:00 2005 +1';
.sp
.fi
.PP
ユーザの有効期限を永久にします。
.sp
.nf
ALTER USER fred VALID UNTIL 'infinity';
.sp
.fi
.PP
ユーザに、他のユーザと新しいデータベースを作成する権限を与えます。
.sp
.nf
ALTER USER miriam CREATEUSER CREATEDB;
.sp
.fi
.SH "互換性"
.PP
\fBALTER USER\fR 文は、PostgreSQL の拡張です。 
標準 SQL では、ユーザの定義は実装に任されています。
.SH "関連項目"
CREATE USER [\fBcreate_user\fR(l)], DROP USER [\fBdrop_user\fR(l)], SET [\fBset\fR(l)]
