.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE DATABASE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE DATABASE \- 新しいデータベースの作成

.SH SYNOPSIS
.sp
.nf
CREATE DATABASE \fIname\fR
    [ [ WITH ] [ OWNER [=] \fIdbowner\fR ]
           [ LOCATION [=] '\fIdbpath\fR' ]
           [ TEMPLATE [=] \fItemplate\fR ]
           [ ENCODING [=] \fIencoding\fR ] ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE DATABASE\fRは新しい PostgreSQLデータベースを作成します。
.PP
データベースを作成するためには、スーパーユーザであるか、特別なCREATEDB権限が必要です。
CREATE USER [\fBcreate_user\fR(l)]を参照してください。
.PP
通常、データベースの作成者がその新しいデータベースの所有者になります。 
スーパーユーザは、\fBOWNER\fR 句を使用することにより、他のユーザを所有者とするデータベースを作成できます。 
スーパーユーザは、特別な権限を保持していないユーザを所有者とするデータベースを作成できます。 
スーパーユーザではない CREATEDB 権限を保持するユーザは、自分自身が所有するデータベースのみ作成できます。
.PP
たとえば別のディスクにデータベースを格納したりするために、代わりの場所を指定することができます。
そのパスは initlocation [\fBinitlocation\fR(1)] コマンドであらかじめ用意しておく必要があります。
.PP
もしパス名がスラッシュ(/)を含まない場合、環境変数名として解釈されます。 
この環境変数はサーバプロセスに知らせなければなりません。 
この方法でデータベース管理者はデータベースを作ることができる場所を管理することができます
（慣習的な選択例は \fBPGDATA2\fR です）。
もしサーバがALLOW_ABSOLUTE_DBPATHSでコンパイルされている場合（デフォルトではそうではありません）、スラッシュで始まることで識別される絶対パス名（たとえば、\fI/usr/local/pgsql/data\fR）も使用することができます。
どちらの場合でも、最終的なパス名は絶対パスでなければならず、単一引用符を含んではなりません。
.PP
デフォルトでは、新しいデータベースは標準システムデータベース template1 を複製することによって作成されます。
別のテンプレートは TEMPLATE \fIname\fR と書くことで指定できます。
特に、TEMPLATE template0と書くことで、使用している \fBPostgreSQL\fR のバージョンによって定義済みの標準オブジェクトのみを持つ新しいデータベースを作ることができます。
これは、もし template1 に追加された、独自にインストールしたオブジェクトのコピーを避けたいという場合に便利です。 
.PP
オプションの符合化方式パラメータを使用してデータベース符合化方式を選択することができます。
指定されないと、選択されたテンプレートデータベースで使われる符合化方式がデフォルトになります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
作成するデータベースの名前です。
.TP
\fB\fIdbowner\fB\fR
新しいデータベースを所有するデータベースユーザの名前です。
もしくは、デフォルト設定 (つまり、コマンドを実行したユーザ) を使用するには、DEFAULT とします。
.TP
\fB\fIdbpath\fB\fR
新しいデータベースを格納するためのファイルシステムの代わりの場所で、文字列リテラルとして指定されます。
もしくはデフォルトの場所を使う場合はDEFAULTです。
.TP
\fB\fItemplate\fB\fR
新しいデータベースを作成するテンプレートの名前、もしくはデフォルトテンプレート（template1）を使うDEFAULTです。
.TP
\fB\fIencoding\fB\fR
新しいデータベースで使われるマルチバイト符号化方式です。
文字列定数（たとえば'SQL_ASCII'）、もしくは整数の符号化番号、もしくはデフォルトの符号化方式を使う DEFAULT です。
.PP
省略可能なパラメータは、上述の順番だけでなく、任意の順番で記述できます。
.PP
.SH "注釈"
.PP
\fBCREATE DATABASE\fRはトランザクションブロックの内側では実行できません。
.PP
ほとんどの場合、``could not initialize database directory''という行が含まれるエラーは、データディスクの権限不足、ディスク容量不足などファイルシステムについての問題に関連するものです。
代替の場所を使用する場合、データベースサーバを稼働するユーザがその場所にアクセスできなければなりません。
.PP
データベースを削除するにはDROP DATABASE [\fBdrop_database\fR(l)]を使用して下さい。
.PP
createdb [\fBcreatedb\fR(1)] プログラムは利便性のために提供される、このコマンドのラッパプログラムです。
.PP
絶対パス名による代わりのデータベースの場所の指定を使用することには、セキュリティ上の問題があります。
そのため、デフォルトでは有効になっていません。
詳細は、[XRef to MANAGE-AG-ALTERNATE-LOCS]を参照してください。
.PP
template1 以外のデータベースの名前をテンプレートに指定することによってデータベースをコピーすることは可能ですが、これは(まだ) 一般的な目的の ``\fBCOPY DATABASE\fR'' 機能として意図されているわけではありません。
テンプレートとして使用するデータベースは読み取り専用として扱うことを推奨します。
より詳細は[XRef to MANAGE-AG-TEMPLATEDBS]を参照して下さい。
.SH "例"
.PP
新しいデータベースを作成します。
.sp
.nf
CREATE DATABASE lusiadas;
.sp
.fi
.PP
代替領域 \fI~/private_db\fR に新しいデータベースを作成するには、シェルから以下を実行します。
.sp
.nf
mkdir private_db
initlocation ~/private_db
.sp
.fi
そして、\fBpsql\fRセッションから以下を実行します。
.sp
.nf
CREATE DATABASE elsewhere WITH LOCATION '/home/olly/private_db';
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBCREATE DATABASE\fR 文はありません。 
データベースは、実装で生成が定義されるカタログと同等のものです。
