.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OPERATOR CLASS" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP OPERATOR CLASS \- 演算子クラスの削除

.SH SYNOPSIS
.sp
.nf
DROP OPERATOR CLASS \fIname\fR USING \fIindex_method\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP OPERATOR CLASS\fR は既存の演算子クラスを削除します。
このコマンドを実行するには、演算子クラスの所有者でなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の演算子クラスの名前です (スキーマ修飾名でも可)。
.TP
\fB\fIindex_method\fB\fR
この演算子クラスを使用するインデックスアクセスメソッドの名前です。
.TP
\fBCASCADE\fR
この演算子クラスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、その演算子クラスの削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
B-tree 演算子クラス widget_ops を削除します。
.sp
.nf
DROP OPERATOR CLASS widget_ops USING btree;
.sp
.fi
この演算子クラスを使用する既存のインデックスが存在する場合には、このコマンドは実行できません。 
このようなインデックスを演算子クラスとともに削除するには、CASCADE を追加します。
.SH "互換性"
.PP
標準SQL には、\fBDROP OPERATOR CLASS\fR はありません。
.SH "関連項目"
ALTER OPERATOR CLASS [\fBalter_operator_class\fR(l)], CREATE OPERATOR CLASS [\fBcreate_operator_class\fR(l)]
