.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_fnumber" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_fnumber \- 指定した列名から列番号を決定します。

.SH SYNOPSIS
.sp
.nf
int SPI_fnumber(TupleDesc \fIrowdesc\fR, const char * \fIcolname\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_fnumber\fR は指定した名前の列の列番号を返します。
.PP
\fIcolname\fRが(oidなどの)システム列を参照する場合、適切な負の列番号が返されます。
呼び出し元は、エラーを検知するために戻り値が\fBSPI_ERROR_NOATTRIBUTE\fRと正確に同一であるかどうかを注意して検査しなければなりません。
システム列を拒絶させたくなければ、結果が0あるいは0未満かを検査するという方法は、正しくありません。
.SH "引数"
.TP
\fBTupleDesc \fIrowdesc\fB\fR
入力行の記述。
.TP
\fBconst char * \fIcolname\fB\fR
列名。
.SH "戻り値"
.PP
(1から始まる)列番号。
指定された名前の列が見つからなければ、\fBSPI_ERROR_NOATTRIBUTE\fRです。
