.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_DISCONNECT" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_disconnect \- サーバとの接続を閉じます。

.SH SYNOPSIS
.sp
.nf
pg_disconnect \fIconn\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_disconnect\fRはPostgreSQLサーバとの接続を閉じます。
.SH "引数"
.TP
\fB\fIconn\fB\fR
閉ざす接続用のハンドルです。
.SH "戻り値"
.PP
ありません。
