.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TRIGGER" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TRIGGER \- トリガの削除

.SH SYNOPSIS
.sp
.nf
DROP TRIGGER \fIname\fR ON \fItable\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP TRIGGER\fR は既存のトリガ定義を削除します。 
このコマンドを実行するユーザは、トリガが定義されたテーブルの所有者でなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するトリガの名前です。
.TP
\fB\fItable\fB\fR
トリガが定義されたテーブルの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
このトリガに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このトリガの削除を拒否します。これがデフォルトです。
.SH "例"
.PP
テーブル films にあるトリガ if_dist_exists を削除するには以下のようにします。
.sp
.nf
DROP TRIGGER if_dist_exists ON films;
.sp
.fi
.SH "互換性"
.PP
PostgreSQL の \fBDROP TRIGGER\fR 文は標準SQLと互換性がありません。
標準SQLでは、トリガ名はテーブルに局所化されていませんので、そのコマンドは単に DROP TRIGGER \fIname\fR となります。
.SH "関連項目"
CREATE TRIGGER [\fBcreate_trigger\fR(l)]
