.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_cursor_open" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_cursor_open \- SPI_prepareで作成された計画を使用したカーソルを設定します。

.SH SYNOPSIS
.sp
.nf
Portal SPI_cursor_open(const char * \fIname\fR, void * \fIplan\fR, Datum * \fIvalues\fR, const char * \fInulls\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_cursor_open\fR は、\fBSPI_prepare\fRによって準備された計画を実行するカーソル(内部的にはportal)を設定します。
.PP
計画を直接実行するのではなくカーソルを使用することには2つの利点があります。
1つ目は、結果行を1度に少なく取り出し、多くの行を返す問い合わせでのメモリの過使用を防ぐことができる点です。
2つ目は、portalは現在のプロシージャの外部でも有効である点です。(実際、現在のトランザクションの終端まで有効とすることができます。)
プロシージャの呼び出し元にportalの名前を返すことで、結果として行セットを返す手段を提供します。
.SH "引数"
.TP
\fBconst char * \fIname\fB\fR
portalの名前、あるいは、システムに名前を決定させる場合は\fBNULL\fRです。
.TP
\fBvoid * \fIplan\fB\fR
(\fBSPI_prepare\fRで返される)実行計画。
.TP
\fBDatum * \fIvalues\fB\fR
実パラメータ値。
.TP
\fBconst char *\fInulls\fB\fR
どのパラメータがNULLであるかを示す配列。
nはNULL値を表します。(\fIvalues\fR内の項目は無視されます。)
空白は非NULLの値を表します。(\fIvalues\fR内の項目は有効です。)
\fInulls\fR が \fBNULL\fR の場合、\fBSPI_curcor_open\fRはすべてのパラメータがNULLであるとみなします。
.SH "戻り値"
.PP
カーソルを含むportalへのポインタ。
エラーの場合は\fBNULL\fRです。
