.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMIT" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
COMMIT \- 現在のトランザクションのコミット

.SH SYNOPSIS
.sp
.nf
COMMIT [ WORK | TRANSACTION ]
.sp
.fi
.SH "説明"
.PP
\fBCOMMIT\fR は現在のトランザクションをコミットします。
そのトランザクションで行われたすべての変更は他のユーザに見えるようになり、クラッシュが起きても一貫性が保証されます。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。何も影響はありません。
.SH "注釈"
.PP
トランザクションを中断するには ROLLBACK [\fBrollback\fR(l)]を使用して下さい。
.PP
トランザクションの外部で\fBCOMMIT\fRを発行しても害はありません。
ただし、警告メッセージが現われます。
.SH "例"
.PP
現在のトランザクションをコミットし、全ての変更を永続化します。
.sp
.nf
COMMIT;
.sp
.fi
.SH "互換性"
.PP
標準 SQL は COMMIT と COMMIT WORK という2つの形式のみを規定しています。
その他の点は完全な互換性があります。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], ROLLBACK [\fBrollback\fR(l)]
