.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_saveplan" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_saveplan \- 計画を保存します。

.SH SYNOPSIS
.sp
.nf
void * SPI_saveplan(void * \fIplan\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_saveplan\fRは渡された(\fBSPI_prepare\fRで準備された)計画を\fBSPI_finish\fRとトランザクションマネージャで解放されないメモリ内に保存します。
そして、保存した計画のポインタを返します。
これは、現在のセッションにおける、その後のプロシージャの呼び出しで準備された計画を再利用できる機能を提供します。
返されるポインタを局所変数に保存することができます。
計画を準備する時や\fBSPI_execp\fRで既存の準備された計画を使用する時、常にこのポインタが\fBNULL\fRかどうかを検査して下さい。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
保存する計画。
.SH "戻り値"
.PP
保存された計画へのポインタ。
失敗した場合は\fBNULL\fRです。
エラー時、SPI_resultは以下のように設定されます。
.TP
\fBSPI_ERROR_ARGUMENT\fR
\fIplan\fR が \fBNULL\fR の場合。
.TP
\fBSPI_ERROR_UNCONNECTED\fR
未接続のプロシージャから呼び出された場合。
.PP
.SH "注意"
.PP
準備された計画で参照されるオブジェクト(テーブル、関数など)のいずれかがセッションの途中で削除された場合、その計画の\fBSPI_execp\fRの結果は予測できません。
