.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COPY" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
COPY \- ファイルとテーブルの間でのデータのコピー

.SH SYNOPSIS
.sp
.nf
COPY \fItablename\fR [ ( \fIcolumn\fR [, ...] ) ]
    FROM { '\fIfilename\fR' | STDIN }
    [ [ WITH ] 
          [ BINARY ] 
          [ OIDS ]
          [ DELIMITER [ AS ] '\fIdelimiter\fR' ]
          [ NULL [ AS ] '\fInull string\fR' ] ]

COPY \fItablename\fR [ ( \fIcolumn\fR [, ...] ) ]
    TO { '\fIfilename\fR' | STDOUT }
    [ [ WITH ] 
          [ BINARY ]
          [ OIDS ]
          [ DELIMITER [ AS ] '\fIdelimiter\fR' ]
          [ NULL [ AS ] '\fInull string\fR' ] ]
.sp
.fi
.SH "説明"
.PP
\fBCOPY\fRコマンドは、PostgreSQL のテーブルと標準のファイルシステムのファイル間でデータを移動します。 
\fBCOPY TO\fR コマンドはテーブルのすべての内容をファイル\fBに\fRコピーします。 
また、\fBCOPY FROM\fR コマンドは、ファイル\fBから\fRテーブルへとデータをコピーします (このとき、すでにテーブルにあるデータにコピー内容を追加します）。
.PP
列のリストが指定されている場合、\fBCOPY\fR では、指定された列のデータとファイルの間でのみコピーが行われます。 
列リストに入っていない列がテーブル内にある場合、\fBCOPY FROM\fR は、それらの列にデフォルトの値を挿入します。
.PP
ファイル名付きの \fBCOPY\fR コマンドは、PostgreSQL サーバに対して直接ファイルへの読み書きをするように伝えます。
そのファイルは必ずサーバからアクセスでき、またファイル名はバックエンドから見たように指定されなければなりません。
STDIN や STDOUT が指定された場合、データはクライアントとサーバ間を流れます。
.SH "パラメータ"
.TP
\fB\fItablename\fB\fR
既存のテーブルの名前です (スキーマ修飾も可)。
.TP
\fB\fIcolumn\fB\fR
省略可能な、コピーする列のリストです。 
列のリストが指定されていない場合は、すべての列が使用されます。
.TP
\fB\fIfilename\fB\fR
入出力ファイルの絶対パス名です。
.TP
\fBSTDIN\fR
入力がクライアントアプリケーションからのものであることを指定します。
.TP
\fBSTDOUT\fR
出力がクライアントアプリケーションへのものであることを指定します。
.TP
\fBBINARY\fR
すべてのデータをテキストではなくバイナリ書式で読み書きするように設定します。 
バイナリモードでは \fBDELIMITER\fR あるいは \fBNULL\fR オプションを指定することはできません。
.TP
\fBOIDS\fR
各行のOIDをコピーすることを指定します。
(OIDを持たないテーブルにOIDSを指定するとエラーが発生します。)
.TP
\fB\fIdelimiter\fB\fR
ファイルの各行（ライン）の列を区切る一文字を指定します。
デフォルトはタブ文字です。
.TP
\fB\fInull string\fB\fR
NULL 値を表す文字列です。
デフォルトでは \\N（バックスラッシュ N）です。
しかし、場合によっては、例えば、空の文字列の方がよいかもしれません。
.sp
.RS
.B "Note:"
\fBCOPY FROM\fRの場合、この文字列と一致するデータ要素は NULL 値として格納されます。
したがって、そのときには、\fBCOPY TO\fR実行時に使用した同じ文字列を使用したかどうか確認してください。
.RE
.sp
.SH "注釈"
.PP
\fBCOPY\fR は通常のテーブルに対してのみ使用することができます。 
ビューに対しては使用することができません。
.PP
BINARY キーワードはすべてのデータをテキストではなく、バイナリ書式として書き込み/読み込みするように指定します。
通常の COPY コマンドより多少速く動作しますが、バイナリ書式のファイルを異なるマシンアーキテクチャで使用することや他のバージョンのPostgreSQLで使用することはできません。
.PP
\fBCOPY TO\fR の場合は値を読み込むテーブル上にSELECT権限が、\fBCOPY FROM\fR の場合は、値を挿入するテーブル上にINSERT権限が必要です。
.PP
\fBCOPY\fR コマンドで指名されたファイルはクライアントアプリケーションではなく、サーバが直接読み込み/書き込みを行います。
したがって、それらはクライアントではなく、データベースサーバマシン上に存在するか、または、データベースサーバマシンからアクセス可能である必要があります。
また、クライアントではなく PostgreSQL ユーザ（サーバを実行しているユーザID）でアクセスと読み書きができる必要もあります。
サーバがアクセス権限を持つ全てのファイルへの読み込み、書き込みを可能にするため、\fBCOPY\fR でファイルを指名するのは、データベースのスーパーユーザのみに許可されています。
.PP
\fBCOPY\fR は \fBpsql\fR の \fB\\copy\fRとは異なるものであることに注意してください。
\fB\\copy\fR は \fBCOPY FROM STDIN\fR や \fBCOPY TO STDOUT\fR を呼び出し、\fBpsql\fR クライアントからアクセスできるファイルにデータの書き込み/読み込みを行います。
したがって、\fB\\copy\fR コマンドが使用された場合には、ファイルへのアクセスとアクセス権限は、サーバではなく、クライアント側に依存します。
.PP
\fBCOPY\fR で指定されるファイル名を常に絶対パスで記述することをお勧めします。
\fBCOPY TO\fR コマンドの場合ではサーバによって強制的にそうなりますが、\fBCOPY FROM\fR コマンドでは相対パスによって指定されたファイルを読み込むことも可能となっています。
そのパスは、クライアントの作業ディレクトリではなく、サーバプロセスの作業ディレクトリ（データディレクトリの下のどこか）から相対的なディレクトリとして解釈されます。
.PP
\fBCOPY FROM\fR は、宛先テーブル上で任意のトリガーとチェック制約を呼び出しますが、ルールは呼び出しません。
.PP
\fBCOPY\fR では、最初のエラーで処理を停止させます。 
これは、\fBCOPY TO\fR コマンドを実行している際には何ら問題はありませんが、\fBCOPY FROM\fR の場合は、対象となるテーブルは始めのほうの行を受け取り済みです。
これらの行は見えませんし、アクセスすることもできませんが、ディスク領域を占有します。
大きなコピー処理に何度も失敗した場合には、無視できないほど無駄なディスク領域が増えてしまいます。
この無駄な領域を取り戻すために、\fBVACUUM\fR を行う必要があります。
.SH "ファイルの書式"
.SS "テキスト書式"
.PP
\fBCOPY\fRを BINARY オプションなしで使用した場合、読み書きされるデータはテーブルの 1 つの行を 1 行で表したテキストファイルとなります。
行内の列は区切り文字で区切られます。
属性値自体はその属性のデータ型の出力関数で生成された、または、その入力関数で受け付け可能な文字列です。
指定されたヌル値文字列は、列が NULL の場所で使用されます。 
入力ファイルの行にある列数が予期されていたよりも多かったり少なかったりすると、\fBCOPY FROM\fR はエラーを出します。
OIDS が指定された場合、OIDは、ユーザデータの列の前にある、1番目の列として読み書きされます。
.PP
データの終了は、バックスラッシュ-ピリオド(\\.) だけから構成される 1 行で表されます。
ファイルの終了によって、完全に同じ機能を提供することができますので、データ終了マークは、ファイルから読み込む際には不要です。 
しかし、3.0以前のクライアントプロトコルを使用したクライアントアプリケーションへ、または、からのデータコピーの場合だけは、終了マークを与えなければなりません。
.PP
バックスラッシュ文字 (\\) は \fBCOPY\fR 対象データ内で、行や列の区切り文字と判定されてしまう可能性があるデータ文字列をクォートすることに使用することができます。
特に、バックスラッシュ自体、改行、使用中の区切り文字といった文字が列値の一部となっている場合は \fB必ず\fR バックスラッシュを前に付けなければなりません。
.PP
以下の特別なバックスラッシュから始まる文字の並びは、\fBCOPY FROM\fR によって解釈されます。
文字の並び表現\\bバックスペース (ASCII 8)\\f改ページ (ASCII 12)\\n改行 (ASCII 10)\\r復帰 (ASCII 13)\\tタブ (ASCII 9)\\v垂直タブ (ASCII 11)\\\fI数字\fRバックスラッシュに続き、1 から 3 個の 8 進数で表す数字によって、そのコード番号が示す文字を指定します。
現在、\fBCOPY TO\fR は 8 進数数字のバックスラッシュ並びを出力することはありませんが、上記一覧に存在しない制御文字には、これを使用します。
.PP
N またはピリオド (.) というデータ文字の前には、バックスラッシュを決して付けないで下さい。
この組み合わせは、それぞれ、ヌル文字とデータ終了マークのデフォルトと間違って解釈されてしまいます。
上で示した以外のバックスラッシュ文字はそのまま解釈されます。
.PP
COPY データを生成するアプリケーションは、データ内の改行と復帰をそれぞれ、\\n と \\r に変換することを強く推奨されています。
現在のところ、バックスラッシュと復帰でデータ内の復帰を表すことも、バックスラッシュと改行でデータ内の改行を表すことも可能です。
しかし、こういった表現は今後のリリースにてデフォルトでは受け付けられなくなります。
また、COPYファイルが異なるマシンを跨って転送される場合、破損のおそれがかなりあります。
(例えば、UnixからWindows、あるいはその逆。)
.PP
\fBCOPY TO\fR は各行の行末にUnix形式の改行(``\\n'')を出力します。
なお、MS Windowsで稼働するサーバの場合は、サーバ上のファイルへの\fBCOPY\fRの場合にのみ復帰/改行(``\\r\\n'')を出力します。
プラットフォームを跨る一貫性のために、サーバのプラットフォームに関わらず、\fBCOPY TO STDOUT\fR は常に``\\n''を送信します。
\fBCOPY FROM\fRは、改行、復帰、復帰/改行を行末として扱うことができます。
データを意図するバックスラッシュの無い改行や復帰によるエラーという危険性を減らすために、\fBCOPY FROM\fR は、入力行の終りが全て共通でない場合に警告を発します。
.SS "バイナリ形式"
.PP
\fBCOPY BINARY\fR で使用されるファイル書式は PostgreSQL 7.4 で変更されました。
新しい書式は、ファイルヘッダ、行データを含むゼロ以上のタプル、ファイルトレーラから構成されます。
ヘッダとデータは、ネットワークバイトオーダになりました。
.SS "ファイルヘッダ"
.PP
ファイルヘッダは15バイトの固定フィールドとその後に続く可変長ヘッダ拡張領域から構成されます。
固定フィールドは以下の通りです。
.TP
\fB署名\fR
PGCOPY\\n\\377\\r\\n\\0という11バイトの並びです。
ヌルバイトがこの署名の必須部分となっていることに注意してください。
(この署名は、8ビットを通過させない転送によって破損してしまったファイルを容易に識別できるように設計されています。この署名は改行コード変換やヌルバイトの削除、上位ビット落ち、パリティの変更などによって変わってしまいます。)
.TP
\fBフラグフィールド\fR
このファイル書式の重要な部分となる32ビット整数のビットマスクです。
ビットは0(LSB) から 31 (MSB)までの番号がついています。
このフィールドは、このファイル書式で使用される他の全ての整数フィールドと同様、(最大バイトが最初に現れる)ネットワークバイトオーダで保存されていることに注意してください。
ファイル書式における致命的な問題を表すために、16-31ビットは予約されています。
この範囲に想定外のビットが設定されていることが判明した場合、読み込み先は処理を中断しなければなりません。
後方互換書式問題を通知するために、0-15ビットは予約されています。
この範囲に想定外のビットが設定されていても、読み込み先は単に無視すべきです。
現在、1つのフラグビットのみが定義されており、残りは0でなければなりません。
.RS
.TP
\fBビット16\fR
1ならば、OIDがデータに含まれています。
0ならば、含まれていません。
.RE
.PP
.TP
\fBヘッダ拡張領域長\fR
32ビット整数であり、それ自身を含まない、ヘッダの残り部分のバイト長です。
現在、これは0で、すぐ後に最初のタプルが続きます。
今後、ヘッダ内に追加データを格納できるような書式の変更があるかもしれません。
読み込み先では、どのように扱うか分からない、全てのヘッダ拡張データを単に飛ばさなければなりません。
.PP
.PP
ヘッダ拡張領域は、それ自身で認識することができる塊の並びを保持するために考えられています。
フラグフィールドは読み込み先に拡張領域の内容を知らせるものではありません。
ヘッダ拡張内容の特定の設計は後のリリースのために残してあります。
.PP
この設計は、後方互換性のあるヘッダの追加（ヘッダ拡張チャンクの追加や下位フラグビットの設定）と後方互換性のない変更（変更を知らせるための高位フラグビットの設定や必要に応じた拡張領域へのサポート情報追加）に有効です。
.SS "タプル"
.PP
すべてのタプルはタプル内のフィールド数を表す16ビット整数から始まります（現時点では、テーブル内のすべてのタプルは同一のフィールド数を持つようになっていますが、常にそうであるとは限りません）。 
その後に、タプル中のそれぞれのフィールドが、フィールドデータが何バイトあるかを表す32ビット長のワードの後に、繰り返し続きます。
(このバイト長ワードにはそれ自身は含まれず、0になることもあります。)
特殊な場合として、-1 はNULLフィールドを表す値です。
このNULLの場合、値用のバイトはありません。
.PP
フィールド間には整列用の詰めものやその他余計なデータはありません。
.PP
現在、\fBCOPY BINARY\fR ファイル内の全てのデータ値は、バイナリ書式(書式コード1)であると仮定されています。
将来の拡張によって、列単位の書式コードを指定できるようなヘッダフィールドが追加されることを予想したものです。
.PP
実際のタプルデータに適切なバイナリ書式を決定するためには、PostgreSQLのソース、特に各列のデータ型用の\fB*send\fR 関数と \fB*recv\fR関数(通常配布物内の\fIsrc/backend/utils/adt\fRディレクトリにあります)を調べなければなりません。
.PP
このファイルにOIDが含まれる場合、OIDフィールドがフィールド数ワードのすぐ後に続きます。
これは、フィールドカウントを持たない点を除いて、通常のフィールドです。
特に、これには長さワードがあり、このワードにより、苦労すること無く、4バイトのOIDも8バイトのOIDも扱うことができます。
また、これにより、それが望ましいと判れば、OIDをNULLとして表示することができます。
.SS "ファイルトレーラ"
.PP
ファイルトレーラは、-1を含んだ、16ビット整数ワードで構成されます。 
これはタプルのフィールドカウントワードを使用することによって容易に見分けることができます。
.PP
読み込み先は、フィールドカウントワードが-1でもなく、想定した列数でもなかった場合はエラーを報告しなければなりません。
これは、何らかの理由でデータとの同期が取れなくなったことを判定する特別な検査を提供します。
.SH "例"
.PP
以下の例では、フィールド区切り文字として縦棒(|)を使用してテーブルをクライアントにコピーします。
.sp
.nf
COPY country TO STDOUT WITH DELIMITER '|';
.sp
.fi
.PP
ファイルからcountryテーブルにデータをコピーします。
.sp
.nf
COPY country FROM '/usr1/proj/bray/sql/country_data';
.sp
.fi
.PP
これはSTDINからテーブルにコピーするのに適したデータの例です。
.sp
.nf
AF      AFGHANISTAN
AL      ALBANIA
DZ      ALGERIA
ZM      ZAMBIA
ZW      ZIMBABWE
.sp
.fi
各行の空白文字は実際にはタブ文字であることに注意してください。
.PP
以下は同一のデータをバイナリ書式で出力したものです。
データを Unix ユーティリティ\fBod -c\fR を使ってフィルタしたものを示しています。
テーブルには3列あり、最初のデータ型は\fBchar(2)\fR、2番目は\fBtext\fR、3番目は\fBinteger\fRです。
全ての行の3列目はNULL値です。
.sp
.nf
0000000   P   G   C   O   P   Y  \\n 377  \\r  \\n  \\0  \\0  \\0  \\0  \\0  \\0
0000020  \\0  \\0  \\0  \\0 003  \\0  \\0  \\0 002   A   F  \\0  \\0  \\0 013   A
0000040   F   G   H   A   N   I   S   T   A   N 377 377 377 377  \\0 003
0000060  \\0  \\0  \\0 002   A   L  \\0  \\0  \\0 007   A   L   B   A   N   I
0000100   A 377 377 377 377  \\0 003  \\0  \\0  \\0 002   D   Z  \\0  \\0  \\0
0000120 007   A   L   G   E   R   I   A 377 377 377 377  \\0 003  \\0  \\0
0000140  \\0 002   Z   M  \\0  \\0  \\0 006   Z   A   M   B   I   A 377 377
0000160 377 377  \\0 003  \\0  \\0  \\0 002   Z   W  \\0  \\0  \\0  \\b   Z   I
0000200   M   B   A   B   W   E 377 377 377 377 377 377
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBCOPY\fR文はありません。
.PP
以下の構文は、PostgreSQLバージョン7.3以前で使用されていたもので、まだサポートされています。
.sp
.nf
COPY [ BINARY ] \fItablename\fR [ WITH OIDS ]
    FROM { '\fIfilename\fR' | STDIN }
    [ [USING] DELIMITERS '\fIdelimiter\fR' ]
    [ WITH NULL AS '\fInull string\fR' ]

COPY [ BINARY ] \fItablename\fR [ WITH OIDS ]
    TO { '\fIfilename\fR' | STDOUT }
    [ [USING] DELIMITERS '\fIdelimiter\fR' ]
    [ WITH NULL AS '\fInull string\fR' ]
.sp
.fi
