.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "MOVE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
MOVE \- カーソルの位置決め

.SH SYNOPSIS
.sp
.nf
MOVE [ \fIdirection\fR { FROM | IN } ] \fIcursorname\fR
.sp
.fi
.SH "説明"
.PP
\fBMOVE\fR はデータを取り出すこと無くカーソルの位置を変更します。
\fBMOVE\fR は \fBFETCH\fR コマンドと全く同じように動作しますが、カーソルの位置を変えるだけで行を返しません。
.PP
構文と使用方法についての詳細はFETCH [\fBfetch\fR(l)]を参照してください。
.SH "出力"
.PP
正常に終了すると、\fBMOVE\fR は以下の形式のコマンドタグを返します。
.sp
.nf
MOVE \fIcount\fR
.sp
.fi
\fIcount\fR は移動した行数です。
(0の場合もあります。)
.SH "例"
.sp
.nf
BEGIN WORK;
DECLARE liahona CURSOR FOR SELECT * FROM films;

-- 最初の5行を飛ばします。
MOVE FORWARD 5 IN liahona;
MOVE 5

-- liahona カーソル内の 6行目を抽出します。
FETCH 1 FROM liahona;
 code  | title  | did | date_prod  |  kind  |  len
-------+--------+-----+------------+--------+-------
 P_303 | 48 Hrs | 103 | 1982-10-22 | Action | 01:37
(1 row)

-- liahona カーソルを閉じ、トランザクションを終了します。
CLOSE liahona;
COMMIT WORK;
.sp
.fi
.SH "互換性"
.PP
標準 SQL には \fBMOVE\fR 文はありません。
