.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_copytupledesc" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_copytupledesc \- 上位エグゼキュータコンテキスト内に行記述子のコピーを作成します。

.SH SYNOPSIS
.sp
.nf
TupleDesc SPI_copytupledesc(TupleDesc \fItupdesc\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_copytupledesc\fRは上位エグゼキュータコンテキスト内に行記述子のコピーを作成します。
.SH "引数"
.TP
\fBTupleDesc \fItupdesc\fB\fR
コピーされる行記述子。
.SH "戻り値"
.PP
コピーされた行記述子。
\fItupdesc\fR が \fBNULL\fRの場合のみ\fBNULL\fRです。
