.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP AGGREGATE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP AGGREGATE \- 集約関数の削除

.SH SYNOPSIS
.sp
.nf
DROP AGGREGATE \fIname\fR ( \fItype\fR ) [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP AGGREGATE\fR を実行すると、既存の集約関数定義を削除することができます。 このコマンドを実行するには、現在のユーザがその集約関数を所有している必要があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の集約関数の名前です (スキーマ修飾名でも可)。
.TP
\fB\fItype\fB\fR
集約関数の入力データ型を指定します。または、関数が任意のデータ型の入力を受け付ける場合は、* を指定します。
.TP
\fBCASCADE\fR
その集約関数に依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その集約関数の削除要求を拒否します。これがデフォルトです。
.SH "例"
.PP
integer 型の myavg 集約関数を削除するには、以下のようにします。
.sp
.nf
DROP AGGREGATE myavg(integer);
.sp
.fi
.SH "互換性"
.PP
標準 SQL には、\fBDROP AGGREGATE\fR 文はありません。 
.SH "関連項目"
ALTER AGGREGATE [\fBalter_aggregate\fR(l)], CREATE AGGREGATE [\fBcreate_aggregate\fR(l)]
