.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER SCHEMA" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER SCHEMA \- スキーマ定義を変更

.SH SYNOPSIS
.sp
.nf
ALTER SCHEMA \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER SCHEMA\fR はスキーマ定義を変更します。
唯一の機能はスキーマ名の変更です。
スキーマ名を変更するには、そのスキーマを所有する必要があり、また、そのデータベース上のCREATE 権限が必要です。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
スキーマ名です。
.TP
\fB\fInewname\fB\fR
新しいスキーマ名です。
.SH "互換性"
.PP
標準SQLには\fBALTER SCHEMA\fR文はありません。
.SH "関連項目"
CREATE SCHEMA [\fBcreate_schema\fR(l)], DROP SCHEMA [\fBdrop_schema\fR(l)]
