.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_finish" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_finish \- プロシージャをSPIマネージャから切断します。

.SH SYNOPSIS
.sp
.nf
int SPI_finish(void)
.sp
.fi
.SH "説明"
.PP
\fBSPI_finish\fRは既存のSPIマネージャへの接続を切断します。
プロシージャの現在の呼び出し期間内で必要なSPI操作が完了した後この関数を呼び出さなければなりません。
しかし、elog(ERROR)経由でトランザクションを中断させる場合は、この関数が何を行なうかを気にする必要はありません。
その場合、SPIは自動的に自身を整理します。
.PP
\fBSPI_finish\fRが、有効な接続がない状態で呼び出された場合、\fBSPI_ERROR_UNCONNECTED\fRが返されます。
この場合根本的な問題はありません。SPIマネージャは特に行なうことがないことを意味します。
.SH "戻り値"
.TP
\fBSPI_OK_FINISH\fR
適切に切断された場合
.TP
\fBSPI_ERROR_UNCONNECTED\fR
未接続のプロシージャから呼び出された場合
