.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_CLOSE" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_close \- ラージオブジェクトを閉じます。

.SH SYNOPSIS
.sp
.nf
pg_lo_close \fIconn\fR \fIdescriptor\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_close\fRはラージオブジェクトを閉じます。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIdescriptor\fB\fR
\fBpg_lo_open\fRによるラージオブジェクト用の記述子です。
.SH "戻り値"
.PP
ありません。
