.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_EXPORT" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_export \- ラージオブジェクトをファイルにエクスポートします。

.SH SYNOPSIS
.sp
.nf
pg_lo_export \fIconn\fR \fIloid\fR \fIfilename\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_export\fRは指定したラージオブジェクトをファイルに書き出します。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIloid\fB\fR
ラージオブジェクトのOIDです。
.TP
\fB\fIfilename\fB\fR
データのエキスポート先のファイルを指定します。
.SH "戻り値"
.PP
ありません。
.SH "注意"
.PP
\fBpg_lo_export\fRは\fBBEGIN\fR/\fBCOMMIT\fRトランザクションブロック内部で呼び出さなければなりません。
