.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMENT" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
COMMENT \- オブジェクトのコメントの定義、または変更

.SH SYNOPSIS
.sp
.nf
COMMENT ON
{
  TABLE \fIobject_name\fR |
  COLUMN \fItable_name\fR.\fIcolumn_name\fR |
  AGGREGATE \fIagg_name\fR (\fIagg_type\fR) |
  CONSTRAINT \fIconstraint_name\fR ON \fItable_name\fR |
  DATABASE \fIobject_name\fR |
  DOMAIN \fIobject_name\fR |
  FUNCTION \fIfunc_name\fR (\fIarg1_type\fR, \fIarg2_type\fR, ...) |
  INDEX \fIobject_name\fR |
  OPERATOR \fIop\fR (\fIleftoperand_type\fR, \fIrightoperand_type\fR) |
  RULE \fIrule_name\fR ON \fItable_name\fR |
  SCHEMA \fIobject_name\fR |
  SEQUENCE \fIobject_name\fR |
  TRIGGER \fItrigger_name\fR ON \fItable_name\fR |
  TYPE \fIobject_name\fR |
  VIEW \fIobject_name\fR
} IS \fI'text'\fR
.sp
.fi
.SH "説明"
.PP
\fBCOMMENT\fRは、データベースオブジェクトに関するコメントを保存します。
コメントは、\fBpsql\fRの\fB\\dd\fR、\fB\\d+\fR、\fB\\l+\fR などで簡単に取り出すことができます。
\fBobj_description()\fR と \fBcol_description()\fR という名前の、\fBpsql\fR が使用している組み込み関数を使用するように構築することで、他のユーザインタフェースでコメントを取り出すことができます。
.PP
コメントを編集するには、同一オブジェクトに対して新しく \fBCOMMENT\fR コマンドを発行してください。
各オブジェクトに保存されるコメント文字列は 1 つだけです。
コメントを削除するには、NULL をテキスト文字列の部分に書いてください。
オブジェクトが削除された時、コメントは自動的に削除されます。
.SH "パラメータ"
.TP
\fB\fIobject_name\fB\fR
.TP
\fB\fItable_name.column_name\fB\fR
.TP
\fB\fIaggname\fB\fR
.TP
\fB\fIconstraint_name\fB\fR
.TP
\fB\fIfunc_name\fB\fR
.TP
\fB\fIop\fB\fR
.TP
\fB\fIrule_name\fB\fR
.TP
\fB\fItrigger_name\fB\fR
コメントを付けるオブジェクトの名前です。 
テーブル、集約、ドメイン、関数、インデックス、演算子、シーケンス、データ型、およびビューの名前は、スキーマ修飾することができます。
.TP
\fB\fItext\fB\fR
追加するコメントです。
.SH "注釈"
.PP
現在、コメントにはセキュリティー機構は存在しません。
データベースに接続したユーザは誰でも、そのデータベース内のオブジェクトのコメントを参照することができます(しかし、スーパーユーザのみが所有していないオブジェクトに関するコメントを変更することができます)。
そのため、セキュリティ的に致命的な情報をコメントに記載してはいけません。
.SH "例"
.PP
テーブル mytable にコメントを付けます。
.sp
.nf
COMMENT ON TABLE mytable IS 'This is my table.';
.sp
.fi
今度はそのコメントを削除します。
.sp
.nf
COMMENT ON TABLE mytable IS NULL;
.sp
.fi
.PP
いくつか他の例を示します。
.sp
.nf
COMMENT ON AGGREGATE my_aggregate (double precision) IS 'Computes sample variance';
COMMENT ON COLUMN my_table.my_column IS 'Employee ID number';
COMMENT ON DATABASE my_database IS 'Development Database';
COMMENT ON DOMAIN my_domain IS 'Email Address Domain';
COMMENT ON FUNCTION my_function (timestamp) IS 'Returns Roman Numeral';
COMMENT ON INDEX my_index IS 'Enforces uniqueness on employee ID';
COMMENT ON OPERATOR ^ (text, text) IS 'Performs intersection of two texts';
COMMENT ON OPERATOR ^ (NONE, text) IS 'This is a prefix operator on text';
COMMENT ON RULE my_rule ON my_table IS 'Logs updates of employee records';
COMMENT ON SCHEMA my_schema IS 'Departmental data';
COMMENT ON SEQUENCE my_sequence IS 'Used to generate primary keys';
COMMENT ON TABLE my_schema.my_table IS 'Employee Information';
COMMENT ON TRIGGER my_trigger ON my_table IS 'Used for RI';
COMMENT ON TYPE complex IS 'Complex number data type';
COMMENT ON VIEW my_view IS 'View of departmental costs';
.sp
.fi
.SH "互換性"
.PP
標準SQL には \fBCOMMENT\fR はありません。
