.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_READ" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_read \- ラージオブジェクトを読み込みます。

.SH SYNOPSIS
.sp
.nf
pg_lo_read \fIconn\fR \fIdescriptor\fR \fIbufVar\fR \fIlen\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_read\fRは最大\fIlen\fRバイトをラージオブジェクトから\fIbufVar\fRという名前の変数に読み込みます。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIdescriptor\fB\fR
\fBpg_lo_open\fRによるラージオブジェクト用の記述子です。
.TP
\fB\fIbufVar\fB\fR
ラージオブジェクトの一部を格納するバッファ用変数の名前です。
.TP
\fB\fIlen\fB\fR
読み込む最大バイト数です。
.SH "戻り値"
.PP
実際に読み込んだバイト数が返されます。
先にラージオブジェクトの終端に達した場合は、要求値よりも小さくなります。
エラーが発生すると、負の値が返されます。
