.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_EXEC" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_exec \- サーバにコマンドを送信します。

.SH SYNOPSIS
.sp
.nf
pg_exec \fIconn\fR \fIcommandString\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_exec\fRはPostgreSQLサーバにコマンドを送信し、結果を返します。
コマンド結果ハンドルは接続用ハンドルから始まり、ピリオド、結果番号が続いて付けられています。
.PP
Tcl エラーがなかったことが、コマンドが成功したことを示すわけではないことに注意して下さい! 
サーバから返されるエラーメッセージは\fBpg_exec\fRでは、Tcl エラーが生成されるのではなく、失敗という状態の問い合わせ結果として処理されます。
.SH "引数"
.TP
\fB\fIconn\fB\fR
コマンドを実行する接続のハンドルです。
.TP
\fB\fIcommandString\fB\fR
実行するSQLコマンドです。
.SH "戻り値"
.PP
結果ハンドルです。
\fBpgtcl\fRがサーバからの応答を得ることができなかった場合はTclエラーが返されます。
これ以外では、コマンド結果オブジェクトが作成され、そのハンドルが返されます。
このハンドルを\fBpg_result\fRに渡して、そのコマンドの結果を入手することができます。
