.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP FUNCTION" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP FUNCTION \- 関数の削除

.SH SYNOPSIS
.sp
.nf
DROP FUNCTION \fIname\fR ( [ \fItype\fR [, ...] ] ) [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP FUNCTION\fR は既存の関数定義を削除します。
このコマンドを実行するには、その関数の所有者でなければなりません。
関数への引数の型は必ず指定しなければなりません。
異なる引数を持つ同じ名前の関数が複数存在する可能性があるからです。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の関数の名前です (スキーマ修飾名でも可)。
.TP
\fB\fItype\fB\fR
その関数の引数のデータ型です。
.TP
\fBCASCADE\fR
関数に依存するオブジェクト (演算子やトリガなど) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その関数の削除要求を拒否します。これがデフォルトです。
.SH "例"
.PP
このコマンドは平方根関数を削除します。
.sp
.nf
DROP FUNCTION sqrt(integer);
.sp
.fi
.SH "互換性"
.PP
\fBDROP FUNCTION\fR 文は標準 SQL で定義されていますが、このコマンドとは互換性がありません。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)], ALTER FUNCTION [\fBalter_function\fR(l)]
