.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SHOW" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
SHOW \- 実行時パラメータの値の表示

.SH SYNOPSIS
.sp
.nf
SHOW \fIname\fR
SHOW ALL
.sp
.fi
.SH "説明"
.PP
\fBSHOW\fR は、実行時パラメータの現在の設定を表示します。 
これらの変数は、\fBSET\fR 文、\fIpostgresql.conf\fR の編集、(\fBlibpq\fRあるいは\fBlibpq\fRを使用したアプリケーションの使用時は)\fBPGOPTIONS\fR 環境変数、または \fBpostmaster\fR の始動時のコマンドラインフラグを使用して設定することができます。
詳細は [XRef to RUNTIME-CONFIG] を参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
実行時パラメータの名前です。
利用可能なパラメータは [XRef to RUNTIME-CONFIG] と SET [\fBset\fR(l)] マニュアルページに記載されています。
更に、以下の変更できない表示のみのパラメータがあります。
.RS
.TP
\fBSERVER_VERSION\fR
サーバのバージョン番号を示します。
.TP
\fBSERVER_ENCODING\fR
サーバ側の文字セット符号化方式を表示します。
現時点では、符号化方式がデータベース作成時に決定されるものであるため、このパラメータは表示のみで変更することができません。
.TP
\fBLC_COLLATE\fR
データベースの照合(テキストの順序付け)についてのロケール設定を示します。
現時点では、この設定が\fBinitdb\fR時に決定されるものであるため、このパラメータは表示のみで変更することができません。
.TP
\fBLC_CTYPE\fR
文字分類についてのデータベースのロケール設定を表示します。
現時点では、この設定が\fBinitdb\fR時に決定されるものであるため、このパラメータは表示のみで変更することができません。
.TP
\fBIS_SUPERUSER\fR
現在のセッションの認証識別子がスーパーユーザ権限を持つ場合はTrueになります。
.RE
.PP
.TP
\fBALL\fR
現在のセッションパラメータのすべての値を表示します。
.SH "注釈"
.PP
\fBcurrent_setting\fR 関数は同等の出力を生成します。
[XRef to FUNCTIONS-MISC]を参照してください。
.SH "例"
.PP
DateStyle パラメータの現在の設定を表示します。
.sp
.nf
SHOW DateStyle;
 DateStyle
-----------
 ISO, MDY
(1 row)
.sp
.fi
.PP
geqo パラメータの現在の設定を表示します。
.sp
.nf
SHOW geqo;
 geqo
------
 on
(1 row)
.sp
.fi
.PP
全設定を表示します。
.sp
.nf
SHOW ALL;
             name              |                setting
-------------------------------+---------------------------------------
 australian_timezones          | off
 authentication_timeout        | 60
 checkpoint_segments           | 3
    .
    .
    .
 wal_debug                     | 0
 wal_sync_method               | fdatasync
(94 rows)
.sp
.fi
.SH "互換性"
.PP
\fBSHOW\fR コマンドは PostgreSQL の拡張です。
.SH "関連項目"
SET [\fBset\fR(l)]
