.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "LOAD" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
LOAD \- 共有ライブラリファイルの読み込み、または、再読み込み

.SH SYNOPSIS
.sp
.nf
LOAD '\fIfilename\fR'
.sp
.fi
.SH "説明"
.PP
このコマンドは、共有ライブラリファイルを PostgreSQL サーバのアドレス空間にロードします。
そのファイルが以前にロードされたものであれば、まず、アンロードします。
このコマンドはサーバがこれまでに読み込んでいた共有ライブラリファイルの内容に変更があった場合に、それをアンロードし、再度ロードし直す時に主に使用されます。
共有ライブラリを使用できるようにするためには、その関数は CREATE FUNCTION [\fBcreate_function\fR(l)] コマンドを使用して宣言されていなければなりません。
.PP
このファイル名は、CREATE FUNCTION [\fBcreate_function\fR(l)]における共有ライブラリ名と同じ方法で特定され、特に、検索パスやシステム標準の共有ライブラリファイル名拡張子の自動付与に依存する可能性があります。
より詳細については [XRef to XFUNC] を参照して下さい。
.SH "互換性"
.PP
\fBLOAD\fR は PostgreSQLの拡張です。
.SH "関連項目"
.PP
CREATE FUNCTION [\fBcreate_function\fR(l)]
