.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CLOSE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CLOSE \- カーソルを閉じる

.SH SYNOPSIS
.sp
.nf
CLOSE \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBCLOSE\fR は開いたカーソルに関連するリソースを解放します。
カーソルが閉じられた後は、そのカーソルに対する操作はできません。
カーソルは必要がなくなったときに閉じるべきです。
.PP
トランザクションが \fBCOMMIT\fR もしくは \fBROLLBACK\fR で終了された時点で、開いているカーソルすべてに対して暗黙的な閉鎖が実行されます。
\fBROLLBACK\fR により、保持可能カーソルを作成したトランザクションが中断した場合、保持可能カーソルは暗黙的に閉ざされます。
作成したトランザクションが正常にコミットされた場合、保持可能カーソルは明示的な \fBCLOSE\fR が実行されるまで、あるいは、クライアントとの接続が切断されるまで、開いたままです。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
閉じる対象の、現在開いているカーソルの名前です。
.SH "注釈"
.PP
PostgreSQL は明示的な \fBOPEN\fR カーソル文を持ちません。 
カーソルは宣言されたときに開いているとみなれます。
カーソルの宣言には \fBDECLARE\fR 文を使用してください。
.SH "例"
.PP
liahona カーソルを閉じます。
.sp
.nf
CLOSE liahona;
.sp
.fi
.SH "互換性"
.PP
\fBCLOSE\fR は標準 SQL と完全に互換性があります。
