.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE USER" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE USER \- 新しいデータベースユーザアカウントの定義

.SH SYNOPSIS
.sp
.nf
CREATE USER \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

 ここで \fIoption\fR は以下のとおりです。
    
    
      SYSID \fIuid\fR 
    | [ ENCRYPTED | UNENCRYPTED ] PASSWORD '\fIpassword\fR'
    | CREATEDB | NOCREATEDB
    | CREATEUSER | NOCREATEUSER
    | IN GROUP \fIgroupname\fR [, ...]
    | VALID UNTIL '\fIabstime\fR' 
.sp
.fi
.SH "説明"
.PP
\fBCREATE USER\fR は、PostgreSQL クラスタに、新しいユーザを加えます。
ユーザの管理と認証に関する情報については、[XRef to USER-MANAG] と [XRef to CLIENT-AUTHENTICATION] を参照して下さい。
このコマンドを使用するにはデータベースのスーパーユーザでなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
ユーザの名前です。
.TP
\fB\fIuid\fB\fR
SYSID 句を使用して、作成されるユーザの PostgreSQL ユーザ ID を選択することができます。
これは通常必要ありませんが、所有者がいなくなったオブジェクトの所有者を再作成しなければならない場合に有用になるかもしれません。

この句が指定されない場合、割り当て済みのユーザ ID の最大値に 1 を足したものがデフォルトとして使われます (100 が最小値です)。
.TP
\fB\fIpassword\fB\fR
ユーザのパスワードを設定します。
もしパスワード認証を使う予定がなければこのオプションは省略できます。 
しかし、パスワード認証を行うよう変更した場合このユーザは接続できません。 
ALTER USER [\fBalter_user\fR(l)] を使用して、後でパスワードを設定することも変更することも可能です。
.TP
\fBENCRYPTED\fR
.TP
\fBUNENCRYPTED\fR
これらのキーワードを使用すると、パスワードを暗号化してシステムカタログに格納するかどうかを制御できます。
(どちらも設定されていない場合のデフォルトの動作は、PASSWORD_ENCRYPTION 設定パラメータによって決まります。) 
指定された文字列がすでに MD5 暗号化書式である場合は、ENCRYPTED、UNENCRYPTED のどちらが指定されているかに関係なく、そのまま保存されます。 
(システムでは、指定された暗号化されたパスワードを復号できないからです。)
これにより、ダンプ/リストアの時に暗号化パスワードを再読み込みすることができます。

古めのクライアントでは、暗号化して保存されたパスワードを使用するために必要な MD5 認証機構をサポートしていない場合があることに注意して下さい。
.TP
\fBCREATEDB\fR
.TP
\fBNOCREATEDB\fR
これらの句はユーザのデータベースの作成に関する権限を定義します。 
CREATEDB が指定された場合、そのユーザは、自己所有のデータベースを作成することができます。 
NOCREATEDB を使用した場合、作成されるユーザには、データベースを作成する権限が与えられません。 
この句を省略した場合は、NOCREATEDB がデフォルトとして使用されます。
.TP
\fBCREATEUSER\fR
.TP
\fBNOCREATEUSER\fR
これらの句は、ユーザが自分で新しいユーザを作成できるかどうかを決定します。
また、このオプションにより、そのユーザは全てのアクセス制限を上書きできるスーパーユーザになります。 
この句を省略した場合、ユーザの属性には NOCREATEUSER が設定されます。
.TP
\fB\fIgroupname\fB\fR
新しいメンバとしてユーザを挿入するグループの名前です。 
複数のグループ名を指定することができます。
.TP
\fB\fIabstime\fB\fR
VALID UNTIL 句は、ユーザのパスワードが有効でなくなるまでの絶対日時を設定します。 
この句が省略された場合、永遠にログイン可能になります。
.SH "注釈"
.PP
ユーザの属性を変更するには ALTER USER [\fBalter_user\fR(l)] を、ユーザを削除するには DROP USER [\fBdrop_user\fR(l)] を使用してください。 
ユーザをグループに追加したり、グループから削除したりするには、ALTER GROUP [\fBalter_group\fR(l)] を使用してください。 
.PP
PostgreSQL には、\fBCREATE USER\fRと同じ機能を持つ (実際は、このコマンドを呼び出しています) プログラム createuser [\fBcreateuser\fR(1)] があり、コマンドシェルから実行することができます。
.SH "例"
.PP
パスワードを持たないユーザを作成します。
.sp
.nf
CREATE USER jonathan;
.sp
.fi
.PP
パスワードを持つユーザを作成します。
.sp
.nf
CREATE USER davide WITH PASSWORD 'jw8s0F4';
.sp
.fi
.PP
アカウントが 2004 年の終りまで有効なパスワードを持つユーザを作成しています。 
2005 年に一秒でも入った後はパスワードは無効になります。
.sp
.nf
CREATE USER miriam WITH PASSWORD 'jw8s0F4' VALID UNTIL '2005-01-01';
.sp
.fi
.PP
データベースを作成することのできるアカウントを作成します。
.sp
.nf
CREATE USER manuel WITH PASSWORD 'jw8s0F4' CREATEDB;
.sp
.fi
.SH "互換性"
.PP
\fBCREATE USER\fR 文は、PostgreSQL の拡張です。
標準 SQL では、ユーザの定義は実装に任されています。
.SH "関連項目"
ALTER USER [\fBalter_user\fR(l)], DROP USER [\fBdrop_user\fR(l)], \fBcreateuser\fR(1)
