.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_ON_CONNECTION_LOSS" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_on_connection_loss \- 予期しない接続切断用のコールバックを設定、変更します。

.SH SYNOPSIS
.sp
.nf
pg_on_connection_loss \fIconn\fR [\fIcallbackCommand\fR]
.sp
.fi
.SH "説明"
.PP
\fBpg_on_connection_loss\fRは、予期しないデータベースとの接続の切断が発生した場合に実行されるコールバックコマンド要求の作成、変更、キャンセルを行ないます。
.PP
コールバックコマンド文字列はTclの待機ループから実行されます。
Tkを使用したアプリケーションでは、これは通常の待機状態です。
Tk以外のTclシェルの場合、\fBupdate\fR もしくは \fBvwait\fR を実行することで、待機ループに入ることができます。
.SH "引数"
.TP
\fB\fIconn\fB\fR
接続切断を監視するハンドルです。
.TP
\fB\fIcallbackCommand\fB\fR
指定された場合、これが接続切断を検出した時に実行されるコマンド文字列になります。
.SH "戻り値"
.PP
ありません。
