.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_CONNDEFAULTS" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_conndefaults \- 接続オプションとそのデフォルト値を取り出します。

.SH SYNOPSIS
.sp
.nf
pg_conndefaults
.sp
.fi
.SH "説明"
.PP
\fBpg_conndefaults\fRは、\fBpg_connect -conninfo\fRで利用できる接続オプションと各オプションの現在のデフォルト値に関する情報を返します。
.SH "引数"
.PP
ありません。
.SH "戻り値"
.PP
結果は、使用可能な接続オプションとその現在のデフォルト値を説明するリストです。
リストの各項目は以下の書式の副リストです。
.sp
.nf
{optname label dispchar dispsize value}
.sp
.fi
ここで、\fIoptname\fRは\fBpg_connect -conninfo\fRのオプションとして使用可能です。
