.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_RESULT" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_result \- コマンド結果に関する情報を取り出します。

.SH SYNOPSIS
.sp
.nf
pg_result \fIresultHandle\fR \fIresultOption\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_result\fRは、事前に\fBpg_exec\fRによって生成されたコマンドオブジェクトに関する情報を返します。
.PP
必要な限り、コマンド結果を保持することができます。
しかし、その後、\fBpg_result -clear\fRを実行して確実に解放してください。
さもないと、メモリリークが発生し、\fBpgtcl\fRは、コマンド結果オブジェクト数が多過ぎるといった警告を出し始めます。
.SH "引数"
.TP
\fB\fIresultHandle\fB\fR
コマンド結果用のハンドルです。
.TP
\fB\fIresultOption\fB\fR
どの結果情報を返すかを指定する、以下のオプションのいずれかです。
.RS
.TP
\fB-status\fR
結果の状態です。
.TP
\fB-error\fR
状態がエラーの場合、エラーメッセージです。
さもなくば、空文字列です。
.TP
\fB-conn\fR
結果を生成した接続です。
.TP
\fB-oid\fR
\fBINSERT\fRコマンドの場合、挿入された行のOIDです。
これ以外では0です。
.TP
\fB-numTuples\fR
問い合わせで返された行数(タプル数)です。
.TP
\fB-cmdTuples\fR
コマンドで影響を受けた行数(タプル数)です。
.TP
\fB-numAttrs\fR
各行の列(属性)数です。
.TP
\fB-assign \fIarrayName\fB\fR
結果を(rowNumber, columnName)という形の添字を使用した配列に代入します。
.TP
\fB-assignbyidx \fIarrayName\fB [\fIappendstr\fB]\fR
結果を、先頭の列の値と残りの列名をキーとした配列に代入します。
\fIappendstr\fRが指定された場合、各キーに追記されます。
まとめると、各行の先頭の列以外のすべてが、(firstColumnValue, columnNameAppendStr)という添字を使用する配列に格納されます。
.TP
\fB-getTuple \fIrowNumber\fB\fR
リスト内の指定された行の列を返します。
行番号は0から始まります。
.TP
\fB-tupleArray \fIrowNumber\fB \fIarrayName\fB\fR
行の列を、列名でインデックスされた\fIarrayName\fR配列に格納します。
行番号は0から始まります。
.TP
\fB-attributes\fR
結果の列名のリストを返します。
.TP
\fB-lAttributes\fR
各列に対して、{name typeOid typeSize}という形の副リストを返します。
.TP
\fB-clear\fR
コマンド結果オブジェクトをクリアします。
.RE
.PP
.SH "戻り値"
.PP
上述のとおり、結果は選択したオプションに依存します。
