.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_execp" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_execp \- SPI_prepareで準備された計画を実行します。

.SH SYNOPSIS
.sp
.nf
int SPI_execp(void * \fIplan\fR, Datum * \fIvalues\fR, const char * \fInulls\fR, int \fIcount\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_execp\fR は、\fBSPI_prepare\fRで準備された計画を実行します。
\fItcount\fRは、\fBSPI_exec\fR と同様の解釈がなされます。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
(\fBSPI_prepare\fRで返される)実行計画。
.TP
\fBDatum *\fIvalues\fB\fR
実パラメータ値。
.TP
\fBconst char * \fInulls\fB\fR
どのパラメータがNULLであるかを示す配列。
nはNULL値を表します。(\fIvalues\fR内の項目は無視されます。)
空白は非NULLの値を表します。(\fIvalues\fR内の項目は有効です。)

\fInulls\fR が \fBNULL\fR の場合、\fBSPI_execp\fRはすべてのパラメータがNULLであるとみなします。
.TP
\fBint \fIcount\fB\fR
計画が実行される行数。
.SH "戻り値"
.PP
戻り値は、\fBSPI_exec\fR同様、あるいは、以下のいずれかです。
.TP
\fBSPI_ERROR_ARGUMENT\fR
\fIplan\fR が \fBNULL\fR あるいは、\fIcount\fR が0未満の場合。
.TP
\fBSPI_ERROR_PARAM\fR
\fIvalues\fR が \fBNULL\fR 、かつ、\fIplan\fR がパラメータ付きで準備された場合。
.PP
.PP
成功時、SPI_processed とSPI_tuptableが \fBSPI_exec\fR 同様に設定されます。
.SH "注意"
.PP
準備された計画で参照されるオブジェクト(テーブル、関数、など)のいずれかがセッション中に削除された場合、その計画用の\fBSPI_execp\fRの結果は予測不能です。
