.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER DATABASE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER DATABASE \- データベースへの変更

.SH SYNOPSIS
.sp
.nf
ALTER DATABASE \fIname\fR SET \fIparameter\fR { TO | = } { \fIvalue\fR | DEFAULT }
ALTER DATABASE \fIname\fR RESET \fIparameter\fR

ALTER DATABASE \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER DATABASE\fRを使用して、データベースの属性を変更することが できます。
.PP
最初の2形式を使用して、PostgreSQL データベースにおける実行時設定変数のセッションのデフォルト値を変更できます。 
指定された値が、コマンド実行後にデータベースで開始される新規セッションのデフォルト値になります。 
データベースで指定されるデフォルト値により、\fIpostgresql.conf\fR ファイルに記述されている設定や、\fBpostmaster\fR から受け取った設定は上書きされます。
データベースの所有者またはスーパーユーザのみが、そのデータベースのセッションのデフォルト値を変更することができます。
.PP
3番目の形式では、データベースの名前を変更することができます。
データベースの所有者のみが、CREATEDB権限を持っている場合に限り、データベース名を変更できます。
現在のデータベースの名前を変更することはできません。
(必要ならば、別のデータベースに接続してください。)
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
セッションのデフォルト値を変更する対象となるデータベースの名前です。
.TP
\fB\fIparameter\fB\fR
.TP
\fB\fIvalue\fB\fR
指定した設定パラメータについて、このデータベースのセッションのデフォルト値を、指定した値に設定します。 
\fIvalue\fR が DEFAULT であるか、あるいは 等価なRESET が使用されている場合、データベース固有の変数の設定は無効になり、新しいセッションではシステム全体のデフォルト設定が継承されます。 
すべての設定をクリアするには、RESET ALL を使用してください。

使用可能なパラメータ名および値についての詳細は、SET [\fBset\fR(l)] および[XRef to RUNTIME-CONFIG]を参照してください。
.TP
\fB\fInewname\fB\fR
新しいデータベース名です。
.SH "注釈"
.PP
ALTER USER [\fBalter_user\fR(l)] を使用すると、データベースではなく特定のユーザにセッションのデフォルト値を関連付けることもできます。 
競合する場合には、ユーザ固有の設定により、データベース固有の設定が上書きされます。
.SH "例"
.PP
testデータベース内のインデックススキャンをデフォルトで無効にします。
.sp
.nf
ALTER DATABASE test SET enable_indexscan TO off;
.sp
.fi
.SH "互換性"
.PP
\fBALTER DATABASE\fR 文は PostgreSQLの拡張です。
.SH "関連項目"
ALTER USER [\fBalter_user\fR(l)], CREATE DATABASE [\fBcreate_database\fR(l)], DROP DATABASE [\fBdrop_database\fR(l)], SET [\fBset\fR(l)]
