.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_copytupleintoslot" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_copytupleintoslot \- 上位エグゼキュータコンテキスト内に行と記述子のコピーを作成します。

.SH SYNOPSIS
.sp
.nf
TupleTableSlot * SPI_copytupleintoslot(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_copytupleintoslot\fRは、上位エグゼキュータコンテキスト内に行のコピーを作成し、それを\fBTupleTableSlot\fR構造体を埋める形式で返します。
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
コピーされる行。
.TP
\fBTupleDesc \fIrowdesc\fB\fR
コピーされる行記述子。
.SH "戻り値"
.PP
コピーした行と記述子を含む\fBTupleTableSlot\fR。
\fIrow\fR もしくは \fIrowdesc\fR が \fBNULL\fR の場合のみ\fBNULL\fRです。
