.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER AGGREGATE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER AGGREGATE \- 集約関数の定義を変更

.SH SYNOPSIS
.sp
.nf
ALTER AGGREGATE \fIname\fR ( \fItype\fR ) RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER AGGREGATE\fR は集約関数の定義を変更します。
利用可能な唯一の機能は集約関数名の変更です。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の集約関数の名前です。(スキーマ修飾名も可。)
.TP
\fB\fItype\fB\fR
集約関数の引数のデータ型、または、関数が任意のデータ型を受け付ける場合は*です。
.TP
\fB\fInewname\fB\fR
新しい集約関数の名前です。
.SH "例"
.PP
\fBinteger\fR型用のmyavg集約関数の名前をmy_averageに変更します。
.sp
.nf
ALTER AGGREGATE myavg(integer) RENAME TO my_average;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER AGGREGATE\fR文はありません。
.SH "関連項目"
CREATE AGGREGATE [\fBcreate_aggregate\fR(l)], DROP AGGREGATE [\fBdrop_aggregate\fR(l)]
