.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_WRITE" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_write \- ラージオブジェクトに書き込みます。

.SH SYNOPSIS
.sp
.nf
pg_lo_write \fIconn\fR \fIdescriptor\fR \fIbuf\fR \fIlen\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_write\fR は最大\fIlen\fRバイトを\fIbuf\fR変数からラージオブジェクトに書き出します。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIdescriptor\fB\fR
\fBpg_lo_open\fRによるラージオブジェクト用の記述子です。
.TP
\fB\fIbuf\fB\fR
ラージオブジェクトに書き出す文字列です。
(変数名ではなく値そのものです。)
.TP
\fB\fIlen\fB\fR
書き出す最大バイト数です。
書き出す値はこの値よりも小さくなることがあり、その場合、文字列の長さになります。
.SH "戻り値"
.PP
実際に書き出したバイト数が返されます。
通常は要求した値と同一です。
エラーが発生した場合は負の値が返されます。
