.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE VIEW" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE VIEW \- 新しいビューの定義

.SH SYNOPSIS
.sp
.nf
CREATE [ OR REPLACE ] VIEW \fIname\fR [ ( \fIcolumn_name\fR [, ...] ) ] AS \fIquery\fR
.sp
.fi
.SH "説明"
.PP
\fBCREATE VIEW\fR は問い合わせによるビューを定義します。
ビューは物理的な実体として存在するものではありません。
その代わりに、ある問い合わせからビューが参照される度に、指定された問い合わせが実行されます。
.PP
\fBCREATE OR REPLACE VIEW\fR も同様の働きをします。
しかし、同じ名前のビューがすでに存在している場合は、そのビューを置き換えます。 
ビューは、同じ列の集合 (つまり、同じ列名およびデータ型) を生成する新規の問い合わせでのみ、置き換えることができます。
.PP
スキーマ名が付けられている場合 (たとえば、CREATE VIEW myschema.myview ...)、ビューは指定されたスキーマで作成されます。 
スキーマ名がなければ、そのビューは現在のスキーマで作成されます。 
ビューの名前は、同じスキーマ内の他のビュー、テーブル、シーケンス、もしくはインデックスとは異なる名前である必要があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
作成するビューの名前です (スキーマ修飾名でも可)。
.TP
\fB\fIcolumn_name\fB\fR
ビューの列に使用する名前のリストです (省略可能)。 省略されている場合、列名は問い合わせから由来したものになります。
.TP
\fB\fIquery\fB\fR
ビューの列と行を生成する問い合わせ (つまり \fBSELECT\fR 文) です。

有効な問い合わせについての詳細は、SELECT [\fBselect\fR(l)] を参照してください。
.SH "注釈"
.PP
現在のところ、ビューは読み取り専用です。
システムは、ビューに対する挿入、更新、削除を許可しません。
ビューに対する挿入などを他のテーブルに対する適切な処理に書き換えるルールを作成することで、更新可能なビューと同じ効果を得ることができます。 
より詳細な情報については、CREATE RULE [\fBcreate_rule\fR(l)] を参照して下さい。
.PP
ビューを削除するには、\fBDROP VIEW\fR 文を使用します。
.PP
ビューの列の名前と型は指定通りに割り当てられることに注意してください。
例えば、
.sp
.nf
CREATE VIEW vista AS SELECT 'Hello World';
.sp
.fi
は、次の2点から良くありません。
列の名前はデフォルトの?column?になり、列のデータ型はデフォルトの\fBunknown\fRになります。
ビューの結果として文字リテラルを返したい場合は、以下のように使用してください。
.sp
.nf
CREATE VIEW vista AS SELECT text 'Hello World' AS hello;
.sp
.fi
.PP
ビュー内で参照するテーブルへのアクセスは、ビューの所有者の権限で決定されます。
しかし、ビュー内で実行される関数は、ビューを使用する問い合わせから直接その関数が呼び出された場合と同様に扱われます。
したがって、ビューを使用するユーザには、ビュー内で使用される全ての関数を呼び出す権限が必要です。
.SH "例"
.PP
全ての娯楽映画 (Comedy films) から成るビューを作成します。
.sp
.nf
CREATE VIEW comedies AS
    SELECT *
    FROM films
    WHERE kind = 'Comedy';
.sp
.fi
.SH "互換性"
.PP
標準SQL では、\fBCREATE VIEW\fR 文に対しいくつかの追加機能を規定しています。
.sp
.nf
CREATE VIEW \fIname\fR [ ( \fIcolumn\fR [, ...] ) ]
    AS query
    [ WITH [ CASCADE | LOCAL ] CHECK OPTION ]
.sp
.fi
.PP
完全な SQL コマンドのオプション句は、以下の通りです。
.TP
\fBCHECK OPTION\fR
このオプションは、更新される可能性のあるビューに使用します。 
ビューに対する全ての \fBINSERT\fR と \fBUPDATE\fR コマンドは、ビュー定義の条件を満足しているか(つまり、新しいデータがビューを通して可視であるか)どうかチェックされます。 
条件を満たしていない場合、その更新は拒否されます。
.TP
\fBLOCAL\fR
このビューの整合性をチェックします。
.TP
\fBCASCADE\fR
このビューと依存している全てのビューの整合性をチェックします。 
CASCADE または LOCAL のいずれも指定されていない場合は、CASCADE が指定されたものと仮定されます。
.PP
.PP
\fBCREATE OR REPLACE VIEW\fR は PostgreSQL の言語拡張です。
