.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_cursor_close" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_cursor_close \- カーソルを閉じます。

.SH SYNOPSIS
.sp
.nf
void SPI_cursor_close(Portal \fIportal\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_cursor_close\fRは事前に作成されたカーソルを閉じ、そのポータル用の領域を解放します。
.PP
トランザクションの終了時にすべての開いているカーソルが自動的に閉ざされます。
\fBSPI_cursor_close\fRは、リソースの解放をより早めに行ないたい場合にのみ呼び出す必要があります。
.SH "引数"
.TP
\fBPortal \fIportal\fB\fR
カーソルを持つポータル。
