.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "START TRANSACTION" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
START TRANSACTION \- トランザクションブロックの開始

.SH SYNOPSIS
.sp
.nf
START TRANSACTION [ ISOLATION LEVEL { READ COMMITTED | SERIALIZABLE } ] [ READ WRITE | READ ONLY ]
.sp
.fi
.SH "説明"
.PP
このコマンドは新しいトランザクションを開始します。 
隔離レベルもしくは読み取り/書き込みモードが指定されていれば、SET TRANSACTION [\fBset_transaction\fR(l)]が実行されたものとして、新しいトランザクションはその特性を持ちます。
他のすべての点において、このコマンドの振る舞いは BEGIN [\fBbegin\fR(l)] コマンドと同じです。
.SH "パラメータ"
.PP
パラメータの意味については SET TRANSACTION [\fBset_transaction\fR(l)] を参照してください。
.SH "互換性"
.PP
このコマンドは標準SQLに従っていますが、SET TRANSACTION [\fBset_transaction\fR(l)] の互換性の節も参照してください。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)], SET TRANSACTION [\fBset_transaction\fR(l)]
