.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_CREAT" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_creat \- ラージオブジェクトを作成します。

.SH SYNOPSIS
.sp
.nf
pg_lo_creat \fIconn\fR \fImode\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_creat\fRはラージオブジェクトを作成します。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトを作成するデータベースへの接続用ハンドルです。
.TP
\fB\fImode\fB\fR
ラージオブジェクトのアクセスモードです。
INV_READと INV_WRITEのいずれか、もしくは、その論理和をとることができます。
``論理和'' 演算子は |です。
以下に例を示します。
.sp
.nf
[pg_lo_creat $conn "INV_READ|INV_WRITE"]
.sp
.fi
.SH "戻り値"
.PP
作成されたラージオブジェクトのOIDです。
