.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER CONVERSION" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER CONVERSION \- 変換の定義を変更

.SH SYNOPSIS
.sp
.nf
ALTER CONVERSION \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER CONVERSION\fR は変換の定義を変更します。
利用可能な唯一の機能は変換名の変更です。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の変換の名前です。(スキーマ修飾名も可。)
.TP
\fB\fInewname\fB\fR
新しい変換の名前です。
.SH "例"
.PP
iso_8859_1_to_utf_8 から latin1_to_unicodeへの変換の名前を変更します。
.sp
.nf
ALTER CONVERSION iso_8859_1_to_utf_8 RENAME TO latin1_to_unicode;
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBALTER CONVERSION\fR 文はありません。
.SH "関連項目"
CREATE CONVERSION [\fBcreate_conversion\fR(l)], DROP CONVERSION [\fBdrop_conversion\fR(l)]
