.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP GROUP" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP GROUP \- ユーザグループの削除

.SH SYNOPSIS
.sp
.nf
DROP GROUP \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP GROUP\fR は指定されたグループを削除します。
グループの中のユーザは削除されません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存のグループの名前です。
.SH "例"
.PP
グループを削除します。
.sp
.nf
DROP GROUP staff;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBDROP GROUP\fR 文はありません。
.SH "関連項目"
ALTER GROUP [\fBalter_group\fR(l)], CREATE GROUP [\fBcreate_group\fR(l)]
