.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP RULE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP RULE \- 書き換えルールの削除

.SH SYNOPSIS
.sp
.nf
DROP RULE \fIname\fR ON \fIrelation\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP RULE\fR は書換えルールを削除します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するルールの名前です。
.TP
\fB\fIrelation\fB\fR
そのルールが適用されたテーブルもしくはビューの名前です。(スキーマ修飾名でも可。)
.TP
\fBCASCADE\fR
そのルールに依存するオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存するオブジェクトがある場合に削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
書換えルールnewrule を削除します。
.sp
.nf
DROP RULE newrule ON mytable;
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBDROP RULE\fR 文はありません。
.SH "関連項目"
CREATE RULE [\fBcreate_rule\fR(l)]
