.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_freetuptable" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_freetuptable \- SPI_exec や類似の関数によって生成された行セットを解放します。

.SH SYNOPSIS
.sp
.nf
void SPI_freetuptable(SPITupleTable * \fItuptable\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_freetuptable\fRは、以前に\fBSPI_exec\fRなどのSPIコマンド実行関数によって作成された行セットを解放します。
そのため、この関数は通常SPI_tupletableグローバル変数を引数として呼び出されます。
.PP
この関数は
SPIプロシージャが複数のコマンドを実行する必要があり、かつ、初期のコマンドの結果を終まで保持したくない場合に有用です。
解放されない行セットは、\fBSPI_finish\fR 時にすべて解放されることに注意して下さい。
.SH "引数"
.TP
\fBSPITupleTable * \fItuptable\fB\fR
解放する行セットへのポインタ。
