.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "EXECUTE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
EXECUTE \- プリペアードクエリの実行

.SH SYNOPSIS
.sp
.nf
EXECUTE \fIplan_name\fR [ (\fIparameter\fR [, ...] ) ]
.sp
.fi
.SH "説明"
.PP
\fBEXECUTE\fR は、既に準備済みである文を実行する際に使用します。 
準備された文はセッション中にしか存在できないため、準備された文は、同じセッション中の前の段階で \fBPREPARE\fR 文によって作成されたものでなければなりません。
.PP
文を作成した \fBPREPARE\fR 文にパラメータが指定されている場合には、これに適合するパラメータの集合が \fBEXECUTE\fR に渡される必要があります。
渡されないと、エラーになります。 
(関数とは異なり) 準備された文は、パラメータのデータ型や数によって上書きされるすることはありません。 
準備された文の名前は、1 つのデータベースセッション内で一意であることが必要です。
.PP
準備された文の作成と使用方法についての詳細は PREPARE [\fBprepare\fR(l)] を参照してください。
.SH "パラメータ"
.TP
\fB\fIplan_name\fB\fR
実行する準備された文の名前です。
.TP
\fB\fIparameter\fB\fR
準備された文に対するパラメータの実際の値です。 
この値は、この準備された文を作成した \fBPREPARE\fR 文内でこのパラメータ位置に指定したデータ型と互換性のあるデータ型の値を生み出す式である必要があります。
.SH "互換性"
.PP
標準SQLには \fBEXECUTE\fR 文が含まれていますが、これは埋め込み SQL でのみ使用できます。 
また、このバージョンの \fBEXECUTE\fR 文では多少異なる構文が使用されます。
