.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TABLE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TABLE \- テーブルの削除

.SH SYNOPSIS
.sp
.nf
DROP TABLE \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP TABLE\fR はデータベースからテーブルを削除します。
テーブルを削除できるのは、その所有者のみです。 
テーブルを削除するのではなく、テーブルの行を空にするには、\fBDELETE\fR を使用してください。
.PP
\fBDROP TABLE\fR は削除対象のテーブル内に存在するインデックス、ルール、トリガおよび制約もすべて削除します。 
しかし、他のテーブルの外部キー制約によって参照されているテーブルを削除するには CASCADE を指定する必要があります。 (CASCADE は外部キー制約を削除するものであって、その外部キーを持つテーブルそのものを削除するのではありません。）
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するテーブルの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
削除するテーブルに依存しているオブジェクト (ビューなど) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このテーブルの削除を拒否します。これがデフォルトです。
.SH "例"
.PP
2 つのテーブル、films と distributors を削除するには以下のようにします。
.sp
.nf
DROP TABLE films, distributors;
.sp
.fi
.SH "互換性"
.PP
このコマンドは標準SQLに従います。
.SH "関連項目"
ALTER TABLE [\fBalter_table\fR(l)], CREATE TABLE [\fBcreate_table\fR(l)]
