.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE CAST" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE CAST \- 新しいキャストの定義

.SH SYNOPSIS
.sp
.nf
CREATE CAST (\fIsourcetype\fR AS \fItargettype\fR)
    WITH FUNCTION \fIfuncname\fR (\fIargtype\fR)
    [ AS ASSIGNMENT | AS IMPLICIT ]

CREATE CAST (\fIsourcetype\fR AS \fItargettype\fR)
    WITHOUT FUNCTION
    [ AS ASSIGNMENT | AS IMPLICIT ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE CAST\fR を使用すると、新しいキャストを定義できます。 
キャストにより、2 つのデータ型間の変換処理方法を指定します。
以下に例を示します。
.sp
.nf
SELECT CAST(42 AS text);
.sp
.fi
この処理を実行すると、事前に指定された関数、この場合 text(int4)を呼び出し、整数の定数である 42 を \fBtext\fR データ型に変換します。 
(適切なキャストが定義されていない場合、変換処理は失敗します。)
.PP
2 つのデータ型は、\fIバイナリ互換性がある\fR 場合があります。
つまり、``自由に''関数を呼び出すことなくお互いのデータ型に変換することができます。 
この場合、対応する値は、同じ内部表現を使用している必要があります。 
たとえば、データ型 \fBtext\fR および \fBvarchar\fR は、バイナリ互換性があります。 
.PP
デフォルトでは、キャストは明示的なキャスト要求があった場合のみ呼び出し可能です。
明示的なキャストの構文とは、CAST(\fIx\fR AS \fItypename\fR)、\fIx\fR::\fItypename\fR、もしくは \fItypename\fR(\fIx\fR) です。
.PP
キャストに AS ASSIGNMENT オプションを付けると、対象データ型の列に代入する際、暗黙的にそのキャストを呼び出すように設定できます。 
たとえば、foo.f1 が \fBtext\fR 型のカラムであるとします。
.sp
.nf
INSERT INTO foo (f1) VALUES (42);
.sp
.fi
\fBinteger\fR 型から \fBtext\fR 型へ変換するキャストに AS ASSIGNMENT オプションが付けられていれば、上記の SQL 文は実行可能です。
オプションが付いていなければ、実行できません。 
(一般的に、この種のキャストは\fI代入キャスト\fRと呼ばれています。 )
.PP
キャストに AS IMPLICIT オプションを付けると、代入でも、もしくは式の中にあるものでも、すべてのコンテキストで暗黙的にそのキャストを呼び出すように設定できます。 
以下の例を参照してください。
|| は \fBtext\fR 型の引数を受け取りますので、
.sp
.nf
SELECT 'The time is ' || now();
.sp
.fi
という SQL 文は、\fBtimestamp\fR 型から \fBtext\fR 型へ変換するキャストに AS IMPLICIT オプションが付けられている場合のみ実行可能です。 
オプションが付いていなければ、以下のように明示的にキャストを記述する必要があります。
.sp
.nf
SELECT 'The time is ' || CAST(now() AS text);
.sp
.fi
(一般的に、この種のキャストは\fI暗黙キャスト\fRと呼ばれています。 )
.PP
暗黙キャストは、多用しない方が賢明です。 
暗黙的キャストを使用しすぎると、PostgreSQL がコマンドを思わぬ意味に解釈してしまう原因になります。もしくは、複数の解釈が可能なため、コマンドをまったく解読できなくなってしまう可能性もあります。 
経験的には、同じ一般的なデータ型カテゴリのデータ型間で、情報を保持する変換でのみ、暗黙キャストを呼び出し可能にするのが良い方法と思われます。 
たとえば、\fBint2\fR 型から \fBint4\fR 型へのキャストは、暗黙キャストにするのが妥当ですが、\fBfloat8\fR 型から \fBint4\fR 型へのキャストは、おそらく代入キャストのみとすべきでしょう。 
\fBtext\fR 型から \fBint4\fR 型への変換のような、カテゴリを越えるデータ型のキャストは、明示的にのみ使用するのが適切です。
.PP
キャストを作成可能にするには、変換元または変換先のデータ型を所有している必要があります。 
また、バイナリ互換性があるキャストを作成するには、スーパーユーザである必要があります 
(バイナリ互換性があるキャスト変換を誤って使用するとサーバがクラッシュしてしまう可能性が高いことから、この制限が付けられました)。
.SH "パラメータ"
.TP
\fB\fIsourcetype\fB\fR
キャストする変換元のデータ型の名前です。
.TP
\fB\fItargettype\fB\fR
キャストする変換先のデータ型の名前です。
.TP
\fB\fIfuncname\fB(\fIargtype\fB)\fR
この関数は、キャストを実行するために使用します。 
関数名は、スキーマ修飾することができます。
スキーマ修飾されていない場合、関数はパスから検索されます。 
引数のデータ型はキャストの変換元のデータ型と、結果のデータ型はキャストの変換先のデータ型と一致する必要があります。 
.TP
\fBWITHOUT FUNCTION\fR
変換元データ型および変換先データ型は、バイナリ互換性があることを示します。
したがって、キャストを実行するのに関数は必要ありません。
.TP
\fBAS ASSIGNMENT\fR
代入コンテキストで、暗黙的にキャストを呼び出せることを示します。
.TP
\fBAS IMPLICIT\fR
任意のコンテキストで、暗黙的にキャストを呼び出せることを示します。
.SH "注釈"
.PP
ユーザ定義のキャストを削除するには、\fBDROP CAST\fR を使用してください。
.PP
データ型を双方向に変更可能にするには、双方向のキャストを明示的に宣言する必要があることに注意してください。
.PP
PostgreSQL 7.3 より前のバージョンでは、データ型と同じ名前の関数はすべてそのデータ型を返しました。また、異なるデータ型の引数を 1 つ取っていると、これが自動的にキャスト関数とされていました。 この慣習は、スキーマを導入し、システムカタログでバイナリ互換性があるキャストを表現可能になったことにより、禁止されました。 (組み込みキャスト関数は、まだこの命名規則に従っています。しかし、現在は pg_cast でキャストとして示される必要があります。 )
.SH "例"
.PP
関数 int4(text) を使用した \fBtext\fR 型から \fBint4\fR 型へのキャストを作成します。
.sp
.nf
CREATE CAST (text AS int4) WITH FUNCTION int4(text);
.sp
.fi
(このキャストは、システムにすでに事前定義されています。)
.SH "互換性"
.PP
\fBCREATE CAST\fR は、SQL99 ではバイナリ互換性があるデータ型についての規定を行わない点を除き、SQL99 に準拠しています。 
AS IMPLICIT も、PostgreSQL の拡張です。
.SH "関連項目"
.PP
CREATE FUNCTION [\fBcreate_function\fR(l)],
CREATE TYPE [\fBcreate_type\fR(l)],
DROP CAST [\fBdrop_cast\fR(l)]
