.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CLUSTER" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CLUSTER \- インデックスに従ったテーブルのクラスタ化

.SH SYNOPSIS
.sp
.nf
CLUSTER \fIindexname\fR ON \fItablename\fR
CLUSTER \fItablename\fR
CLUSTER
.sp
.fi
.SH "説明"
.PP
\fBCLUSTER\fR は、\fIindexname\fR で指定されたインデックスに基づいた、\fItablename\fR で指定されたテーブルをクラスタ構成するように、PostgreSQL に指示します。
インデックスは前もって \fItablename\fR で定義されていなければなりません。
.PP
テーブルがクラスタ構成されると、インデックス情報に基づいて物理的に再序列されます。 
クラスタ構成は、一回限りの操作です。 
クラスタ構成後にそのテーブルが更新されても、変更はクラスタ構成されません。 
つまり、新規もしくは更新されたタプルを、インデックス順に保管することは行ないません。 
インデックス順に保管したい場合、コマンドを再度入力し、定期的に再クラスタ構成を行います。
.PP
テーブルがクラスタ構成されると、PostgreSQL はどのインデックスでクラスタ構成されたかを記録します。
\fBCLUSTER \fItablename\fB\fR という形式で、以前にクラスタ構成された時と同じインデックスを使用してテーブルをクラスタ構成します。
.PP
パラメータが無い\fBCLUSTER\fR は、呼び出したユーザが所有するデータベース内の全てのテーブル、もし、スーパーユーザが呼び出したのであれば全てのテーブルをクラスタ構成します。
.PP
クラスタ構成を実施中のテーブルでは、ACCESS EXCLUSIVEロックが獲得されています。
これにより、\fBCLUSTER\fR が終るまで、そのテーブルに対するデータベース操作(読み書き両方)を防ぐことができます。
.SH "パラメータ"
.TP
\fB\fIindexname\fB\fR
インデックスの名前です。
.TP
\fB\fItablename\fB\fR
テーブルの名前です。(スキーマ修飾も可。)
.SH "注釈"
.PP
あるテーブル内の1つの行をランダムにアクセスする場合、テーブル内のデータの実際の順序は重要でありません。
とはいえ、テーブル内の特定のデータにより頻繁にアクセスする場合で、それらのデータをグループ化しているインデックスが存在するときは、\fBCLUSTER\fR を使うことによる利益を享受することができます。
テーブルからインデックスの値の範囲や、一致する複数の行を保有する1つのインデックスの値などを要求する場合、\fBCLUSTER\fR は、次のような理由から役に立ちます。
インデックスがひとたび最初に一致する行に対するヒープページを認識すると、一致するすべての他の行もおそらく同じヒープページに存在することになるので、\fBCLUSTER\fR はディスクアクセスを減らして問い合わせ処理の速度を速めます。
.PP
クラスタ処理の間、テーブルデータがインデックス順に並んだ、テーブルの一時コピーが作成されます。 
同様に、テーブルの各インデックスの一時コピーも作成されます。 
したがって、ディスクには、少なくともテーブルとインデックスの合計サイズと同じ容量の空きスペースが必要です。
.PP
\fBCLUSTER\fR はクラスタ構成に関する情報を記録していますので、
一度手作業でクラスタ構成させたいテーブルをクラスタ構成し、テーブルが周期的に再クラスタ構成できるように \fBVACUUM\fR 同様にスケジュールを組むことができます。
.PP
プランナによってテーブルの順序付けに関する統計情報が記録されているため、新しくクラスタ構成されたテーブルに \fBANALYZE\fR を実行することが推奨されます。 
そうしないと、プランナが問い合わせ計画を適切に選択できない可能性があります。
.PP
データをクラスタ構成する別の方法があります。 
\fBCLUSTER\fR コマンドは、指定したインデックス順で元のテーブルを再度順序付けする方法です。
行はインデックスの順序におけるヒープから取り出され、また、ヒープテーブルが順序付けらていない場合、項目はでたらめの順序のページ上に存在するため、移動する行毎に 1 つのディスクページが抽出されることになります。
従って、巨大なテーブルでは低速になることがあります。 
( PostgreSQL にはキャッシュがありますが、大きなテーブルの大多数はキャッシュに収まり切れません。) 
テーブルをクラスタ構成するもう 1 つの方法を以下に示します。
.sp
.nf
CREATE TABLE \fInewtable\fR AS
    SELECT \fIcolumnlist\fR FROM \fItable\fR ORDER BY \fIcolumnlist\fR;
.sp
.fi
この SQL 文では、PostgreSQL のソート用のコードを ORDER BY 句で使用し、必要な順序付けをします。
この方法は通常、順序付けられていないデータに対するインデックススキャンよりも処理時間がずっと短くなります。
その後、古いテーブルを削除し、\fBALTER TABLE...RENAME\fR で \fInewtable\fR を前の名前に書き換えてから、テーブルのインデックスを再生成しても構いません。 
しかし、この方法では、テーブルの OID、制約、外部キー関係、与えられた権限、およびその他の付属情報を保持しません。これらの付属情報は、手動で再作成する必要があります。
.SH "例"
.PP
emp_ind インデックスに基づいて、employeesテーブルをクラスタ構成します。
.sp
.nf
CLUSTER emp_ind ON emp;
.sp
.fi
.PP
以前に使用したインデックスを使用してemployeesリレーションをクラスタ構成します。
.sp
.nf
CLUSTER emp;
.sp
.fi
.PP
データベース内の、以前にクラスタ構成されたテーブル全てをクラスタ構成します。
.sp
.nf
CLUSTER;
.sp
.fi
.SH "互換性"
.PP
標準 SQLには\fBCLUSTER\fR 文はありません。
.SH "関連項目"
clusterdb [\fBclusterdb\fR(1)]
