.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP SEQUENCE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP SEQUENCE \- シーケンスの削除

.SH SYNOPSIS
.sp
.nf
DROP SEQUENCE \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP SEQUENCE\fR はシーケンス番号生成機構を削除します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
シーケンスの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
このシーケンスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存オブジェクトがある場合に、このシーケンスの削除を拒否します。これがデフォルトです。
.SH "例"
.PP
シーケンス serial を削除します。
.sp
.nf
DROP SEQUENCE serial;
.sp
.fi
.SH "互換性"
.PP
標準SQL には \fBDROP SEQUENCE\fR 文はありません。
.SH "関連項目"
CREATE SEQUENCE [\fBcreate_sequence\fR(l)]
