.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE GROUP" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE GROUP \- 新しいグループの定義

.SH SYNOPSIS
.sp
.nf
CREATE GROUP \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

ここで、\fIoption\fR は以下のとおりです。

     SYSID \fIgid\fR
   | USER  \fIusername\fR [, ...]
.sp
.fi
.SH "説明"
.PP
\fBCREATE GROUP\fRはデータベースクラスタに新しいグループを作成します。
このコマンドを使用するにはデータベースのスーパーユーザでなければなりません。
.PP
グループのメンバ資格を変更する場合は ALTER GROUP [\fBalter_group\fR(l)] を、グループを削除する場合は DROP GROUP [\fBdrop_group\fR(l)] を使用してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
グループの名前です。
.TP
\fB\fIgid\fB\fR
SYSID句を使用して、新しいグループの PostgreSQLグループIDを選ぶことができます。
しかし、これは必須ではありません。

これが指定されないと、1から始まり、割り当て済みのグループIDのなかで最も高い数値に1を足した値がデフォルトとして使われます。
.TP
\fB\fIusername\fB\fR
グループに含めるユーザのリストです。既存のユーザでなければいけません。
.SH "例"
.PP
空のグループを作成します。
.sp
.nf
CREATE GROUP staff;
.sp
.fi
.PP
メンバを持つグループを作成します。
.sp
.nf
CREATE GROUP marketing WITH USER jonathan, david;
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBCREATE GROUP\fR はありません。
roleという概念がグループと似ています。
