.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_getbinval" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_getbinval \- 指定した列のバイナリ値を返します。

.SH SYNOPSIS
.sp
.nf
Datum SPI_getbinval(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR, bool * \fIisnull\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_getbinval\fR は指定された列の値を内部形式で(\fBDatum\fRとして)返します。
.PP
この関数はデータ用に新しい領域を確保しません。
参照渡しのデータ型の場合、戻り値は渡された行の内部を示すポインタとなります。
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
対象とする入力行。
.TP
\fBTupleDesc \fIrowdesc\fB\fR
入力行の記述。
.TP
\fBint \fIrownumber\fB\fR
(1から始まる)行番号。
.TP
\fBbool * \fIisnull\fB\fR
列のNULL値についてのフラグ。
.SH "戻り値"
.PP
列のバイナリ値が返されます。
\fIisnull\fRで指し示される変数は、列がNULLならば真に、さもなくば、偽に設定されます。
.PP
エラー時、SPI_result は \fBSPI_ERROR_NOATTRIBUTE\fRに設定されます。
