.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_TELL" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_tell \- ラージオブジェクトの現在のシーク位置を返します。

.SH SYNOPSIS
.sp
.nf
pg_lo_tell \fIconn\fR \fIdescriptor\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_tell\fRは、ラージオブジェクトの先頭から数えた、現在の読みとり/書き込み位置をバイト単位で返します。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIdescriptor\fB\fR
\fBpg_lo_open\fRによるラージオブジェクト用の記述子です。
.SH "戻り値"
.PP
0から始まるバイト単位のオフセットです。
\fBpg_lo_lseek\fRの入力に適しています。
