.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ABORT" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ABORT \- 現在のトランザクションのアボート

.SH SYNOPSIS
.sp
.nf
ABORT [ WORK | TRANSACTION ]
.sp
.fi
.SH "説明"
.PP
\fBABORT\fR は現在のトランザクションをロールバックし、そのトランザクションで行われたすべての更新を廃棄します。
このコマンドは 標準 SQL の ROLLBACK [\fBrollback\fR(l)] コマンドの動作と同一であり、歴史的な理由のためだけに存在しています。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。何も効果がありません。
.SH "注釈"
.PP
トランザクションを正常に終了させる場合は COMMIT [\fBcommit\fR(l)] を使用してください。
.PP
トランザクションの外部で\fBABORT\fRを発行しても害はありませんが、警告メッセージが表示されます。
.SH "例"
.PP
全ての変更を中断します。
.sp
.nf
ABORT;
.sp
.fi
.SH "互換性"
.PP
このコマンドはPostgreSQLの拡張で、歴史的な理由で存在します。
\fBROLLBACK\fR が、これと等価な標準SQLコマンドです。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)]
