.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "TRUNCATE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
TRUNCATE \- テーブルの空化

.SH SYNOPSIS
.sp
.nf
TRUNCATE [ TABLE ] \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBTRUNCATE\fR はテーブルから全ての行を素早く削除します。
これは、条件指定の無い \fBDELETE\fR コマンドと同様の機能ですが、実際にはテーブルをスキャンしないので、このコマンドの方が高速です。
大きなテーブルの場合、このコマンドは最も効率的です。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
空にするテーブルの名前です (スキーマ修飾名でも可)。
.SH "注釈"
.PP
他のテーブルからそのテーブルへの外部キー参照がある場合、\fBTRUNCATE\fRを使用することはできません。
そのような場合の有効性検査は、テーブルスキャンが必要であり、検査を行うことが問題ではありません。
.PP
\fBTRUNCATE\fR はそのテーブルに存在するユーザ定義のON DELETEトリガを全く実行しません。
.SH "例"
.PP
bigtable テーブルを空にします。
.sp
.nf
TRUNCATE TABLE bigtable;
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBTRUNCATE\fR コマンドはありません。
