.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_connect" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_connect \- SPIマネージャにプロシージャを接続

.SH SYNOPSIS
.sp
.nf
int SPI_connect(void)
.sp
.fi
.SH "説明"
.PP
\fBSPI_connect\fR はプロシージャ呼び出しからSPIマネージャへの接続を開きます。
SPIを経由してコマンドを実行させる場合、この関数を呼び出さなければなりません。
SPIユーティリティ関数の中には、未接続のプロシージャから呼び出し可能なものがあります。
.PP
すでにプロシージャが接続済みの場合、\fBSPI_connect\fRはSPI_ERROR_CONNECTエラーを返します。
これは、\fBSPI_connect\fRを呼び出したプロシージャが、直接それ自身で\fBSPI_connect\fRを呼び出す別のプロシージャを呼び出す場合に起こります。
SPIを経由して呼び出されるSQLコマンドがSPIを使用する他の関数を呼び出す場合、SPIマネージャの再帰的な呼び出しは許可されていますが、SPI_connectとSPI_finishを直接入れ子に呼び出すことは禁止されています。
.SH "戻り値"
.TP
\fBSPI_OK_CONNECT\fR
成功した場合。
.TP
\fBSPI_ERROR_CONNECT\fR
エラーが発生した場合。
