.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LISTEN" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_listen \- 非同期通知メッセージ用のコールバックを設定、変更します。

.SH SYNOPSIS
.sp
.nf
pg_listen \fIconn\fR \fInotifyName\fR [\fIcallbackCommand\fR]
.sp
.fi
.SH "説明"
.PP
\fBpg_listen\fR は、PostgreSQLサーバからの非同期通知メッセージの監視要求の作成、変更、キャンセルを行ないます。
\fIcallbackCommand\fRパラメータを付けると、要求が確立します。
さもなくば、既存要求のコマンド文字列が置換されます。
\fIcallbackCommand\fRパラメータを付けないと、以前の要求はキャンセルされます。
.PP
\fBpg_listen\fR要求が確立した後、
その名前を持った通知メッセージがサーバから届く度に、指定されたコマンド文字列が実行されます。
これは、PostgreSQLクライアントアプリケーションがその名前を参照する\fBNOTIFY\fRコマンドを発行した時に発生します。

コマンド文字列はTclの待機ループから実行されます。
Tkを使用したアプリケーションでは、これは通常の待機状態です。
Tk以外のTclシェルの場合、\fBupdate\fR もしくは \fBvwait\fR を実行することで、待機ループに入ることができます。
.PP
\fBpg_listen\fRを使用する場合、直接\fBLISTEN\fRもしくは\fBUNLISTEN\fRSQL文を呼び出さないでください。
\fBpgtcl\fRではこれらの文の発行を管理しています。
しかし、自身から通知メッセージを送信する場合は、\fBpg_exec\fRを使用して\fBNOTIFY\fR 文を呼び出してください。
.SH "引数"
.TP
\fB\fIconn\fB\fR
通知を監視する接続のハンドルです。
.TP
\fB\fInotifyName\fB\fR
監視を開始、停止させる通知条件の名前です。
.TP
\fB\fIcallbackCommand\fB\fR
指定した場合、これが一致する通知が届いた時に実行されるコマンド文字列になります。
.SH "戻り値"
.PP
ありません。
