.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_cursor_find" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_cursor_find \- 既存のカーソルを名前で検索します。

.SH SYNOPSIS
.sp
.nf
Portal SPI_cursor_find(const char * \fIname\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_cursor_find\fRは既存のカーソルを名前で検索します。
これは主に、他の何らかの関数でテキストとして返されたカーソル名の名前解決の際に使用されます。
.SH "引数"
.TP
\fBconst char * \fIname\fB\fR
ポータルの名前です。
.SH "戻り値"
.PP
指定された名前のポータルへのポインタ。見つからない場合は\fBNULL\fRです。
