.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "LISTEN" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
LISTEN \- 通知の監視

.SH SYNOPSIS
.sp
.nf
LISTEN \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBLISTEN\fR は現在のセッションを、通知条件 \fIname\fR のリスナとして登録します。
現在のセッションで既にこの通知条件のリスナとして登録されている場合は何も起こりません。
.PP
このセッションまたは同一データベースに接続している別のセッションによって \fBNOTIFY \fIname\fB\fR が実行されると、現在この通知条件を監視しているセッション全てに対して通知がなされます。 
そして、各セッションは同様に接続中のクライアントアプリケーションに通知します。
より詳細については \fBNOTIFY\fR を参照して下さい。
.PP
\fBUNLISTEN\fR コマンドを使って、セッションに登録された指定通知条件を解除できます。
また、セッションの監視登録は、そのセッションが終了した時点で自動的に削除されます。
.PP
クライアントアプリケーションが通知イベントを検出するために使わなければならない方法は、それがどの PostgreSQL アプリケーションプログラミングインタフェースを使用しているのかに依存します。 
\fBlibpq\fR ライブラリを使用するアプリケーションでは、\fBLISTEN\fR を通常の SQL コマンドとして発行し、その後、ルーチン \fBPQnotifies\fR を定期的に呼び出して通知イベントが受信されたかどうかを調べる必要があります。 
\fBlibpgtcl\fR 等の他のインタフェースの場合は、 通知イベントを扱うためのより高レベルな方法が用意されています。 
実際、\fBlibpgtcl\fR を使ったアプリケーションの場合、プログラマが \fBLISTEN\fR や \fBUNLISTEN\fR を直接発行する必要すらありません。 
詳細については、ご使用のライブラリのドキュメンテーションを参照してください。
.PP
NOTIFY [\fBnotify\fR(l)]には、\fBLISTEN\fR および \fBNOTIFY\fR についてのより広範な説明があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
通知条件の名前です。(任意の識別子です。)
.SH "例"
.PP
\fBpsql\fR から監視/通知処理の設定と実行を行ないます。
.sp
.nf
LISTEN virtual;
NOTIFY virtual;
Asynchronous notification "virtual" received from server process with PID 8448.
.sp
.fi
.SH "互換性"
.PP
標準SQL に \fBLISTEN\fR はありません。
.SH "関連項目"
NOTIFY [\fBnotify\fR(l)], UNLISTEN [\fBunlisten\fR(l)]
