.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_freetuple" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_freetuple \- 上位エグゼキュータコンテキスト内に割り当てられた行を解放します。

.SH SYNOPSIS
.sp
.nf
void SPI_freetuple(HeapTuple \fIrow\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_freetuple\fR は以前に上位エグゼキュータコンテキスト内に割り当てられた行を解放します。
.PP
この関数はもはや通常の\fBheap_freetuple\fRとは異なるものです。
単に既存コードの後方互換性のために保持されています。
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
解放する行。
