.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER FUNCTION" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER FUNCTION \- 関数の定義を変更

.SH SYNOPSIS
.sp
.nf
ALTER FUNCTION \fIname\fR ( [ \fItype\fR [, ...] ] ) RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER FUNCTION\fRは関数定義を変更します。
唯一の機能は関数名の変更です。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の関数名です。(スキーマ修飾名も可。)
.TP
\fB\fItype\fB\fR
関数の引数のデータ型です。
.TP
\fB\fInewname\fB\fR
新しい関数名です。
.SH "例"
.PP
\fBinteger\fR型用のsqrt関数の名前をsquare_rootに変更します。
.sp
.nf
ALTER FUNCTION sqrt(integer) RENAME TO square_root;
.sp
.fi
.SH "互換性"
.PP
標準SQLに\fBALTER FUNCTION\fR 文はありますが、関数名を変更するオプションを提供していません。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)], DROP FUNCTION [\fBdrop_function\fR(l)]
