.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SET TRANSACTION" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
SET TRANSACTION \- 現在のトランザクションの特性の設定

.SH SYNOPSIS
.sp
.nf
SET TRANSACTION
    [ ISOLATION LEVEL { READ COMMITTED | SERIALIZABLE } ] [ READ WRITE | READ ONLY ]
SET SESSION CHARACTERISTICS AS TRANSACTION
    [ ISOLATION LEVEL { READ COMMITTED | SERIALIZABLE } ] [ READ WRITE | READ ONLY ]
.sp
.fi
.SH "説明"
.PP
\fBSET TRANSACTION\fR は現在のトランザクションの特性を設定します。
これはその後のトランザクションには影響をおよぼしません。
\fBSET SESSION CHARACTERISTICS\fR はセッションにおける各トランザクションのデフォルトのトランザクション特性を設定します。
\fBSET TRANSACTION\fRにより個々のトランザクションの特性を上書きすることができます。
.PP
利用可能なトランザクション特性はトランザクションの隔離レベルとトランザクションのアクセスモード(読み書きモードもしくは読み取りのみモード)です。
.PP
トランザクションの隔離レベルは、他のトランザクションが並行して実行している時に、そのトランザクションからどのようなデータを見ることができるかを決定するものです。
.TP
\fBREAD COMMITTED\fR
一つの文はそれが開始される前にコミットされた行のみ見ることができます。
これがデフォルトです。
.TP
\fBSERIALIZABLE\fR
現在のトランザクションはこのトランザクションで最初の問い合わせ文またはデータを変更する文が実行される前にコミットされた行だけを見ることができます。
.sp
.RS
.B "Tip:"
直感的に言うと、シリアライザブルでは、二つの同時に実行されたトランザクションが作り出したデータベースの状態が、あたかもそれぞれが順に実行した場合と同じになるようになります。
.RE
.sp
.PP
トランザクション隔離レベルは、そのトランザクションにおける最初の問い合わせやデータを変更する文
(\fBSELECT\fR, \fBINSERT\fR, \fBDELETE\fR,
\fBUPDATE\fR, \fBFETCH\fR, \fBCOPY\fR) 
が実行された後に設定することはできません。
トランザクションの隔離や同時実行制御についての詳細情報は [XRef to MVCC] を参照してください。
.PP
トランザクションのアクセスモードは、そのトランザクションが読み書き可能か読み取りのみかを決定します。
デフォルトは読み書き可能です。
読み取りのみのトランザクションでは、書き込み対象のテーブルが一時テーブルでない限り、INSERT、UPDATE、DELETE、および COPY TOというSQLコマンドを実行できません。
また、CREATE、ALTER、DROP系のすべてのSQLコマンド、および、COMMENT、GRANT、REVOKE、TRUNCATEは、読み取りのみのトランザクションでは全く実行できません。
更に、EXPLAIN ANALYZEとEXECUTEは、そのコマンドが上述のコマンドを実行するものであれば、実行できません。
これは、ディスクへの書き込み防止を行わない、高度な読み取りのみの表現方法です。
.SH "注釈"
.PP
以下のコマンドや設定ファイルでセッションのデフォルトのトランザクション隔離レベルを設定することができます。
.sp
.nf
SET default_transaction_isolation = '\fIvalue\fR'
.sp
.fi
より詳細は[XRef to RUNTIME-CONFIG]を参照してください。
.SH "互換性"
.PP
どちらのコマンドも標準SQLで定義されています。
標準SQL ではデフォルトのトランザクションは SERIALIZABLE ですが、PostgreSQLでは READ COMMITED が通常のデフォルトです。
しかし、これは上述の通り変更可能です。
PostgreSQL ではREAD UNCOMMITTEDと REPEATABLE READという隔離レベルを提供していません。
多版型同時実行制御のため、SERIALIZABLE は完璧なシリアライザブルではありません。
詳細は[XRef to MVCC]を参照してください。
.PP
標準SQLでは、もう一つ、診断領域の大きさという、トランザクション特性があり、このコマンドで設定可能です。
この概念は組み込みSQLでの使用のみのためのものです。
