.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SET SESSION AUTHORIZATION" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
SET SESSION AUTHORIZATION \- セッションのユーザ識別子、現在のセッションの現在のユーザ識別子の設定

.SH SYNOPSIS
.sp
.nf
SET [ SESSION | LOCAL ] SESSION AUTHORIZATION \fIusername\fR
SET [ SESSION | LOCAL ] SESSION AUTHORIZATION DEFAULT
RESET SESSION AUTHORIZATION
.sp
.fi
.SH "説明"
.PP
このコマンドはセッションのユーザ識別子、並びに、現在のSQLセッションコンテキストにおける現在のユーザ識別子を \fIusername\fR に設定します。
ユーザ名は、識別子として書くことも、文字列リテラルとして書くこともできます。
このコマンドを使用して、例えば、一時的に非特権ユーザとなり、その後に特権ユーザに戻ることが可能です。
.PP
セッションのユーザ識別子はクライアントから渡される(おそらくは認証された)ユーザ名で初期化されます。
現在のユーザ識別子は通常セッションのユーザ識別子と同一ですが、``setuid'' 関数や似たような機構によって一時的に変更することができます。
現在のユーザ識別子は権限の検査に関係します。
.PP
セッションのユーザ識別子は、最初のセッションユーザ (\fI認証されたユーザ\fR) がスーパーユーザ権限を持っている場合にのみ変更できます。 
スーパーユーザ権限を持っていない場合、コマンドは認証されたユーザ名を指定しなければ受け入れられません。
.PP
\fBSESSION\fR 修飾子および \fBLOCAL\fR 修飾子は、通常の SET [\fBset\fR(l)] コマンドの場合と同じように機能します。
.PP
DEFAULT 形式および RESET 形式は、セッションと現在のユーザ識別子を元の認証ユーザにリセットします。
これらの形式は常に受け入れられます。
.SH "例"
.sp
.nf
SELECT SESSION_USER, CURRENT_USER;

 session_user | current_user 
--------------+--------------
 peter        | peter

SET SESSION AUTHORIZATION 'paul';

SELECT SESSION_USER, CURRENT_USER;

 session_user | current_user 
--------------+--------------
 paul         | paul
.sp
.fi
.SH "互換性"
.PP
標準SQLでは、\fIusername\fR リテラルの部分には他の異なった表現を使用できます。
この違いは実際は重要ではありません。
PostgreSQL では識別子構文 ("username") を使用できますが、SQLでは使用できません。
SQLではこのコマンドをトランザクション中に実行することができませんが、PostgreSQL では、禁止する理由が見当たらないため、この制限をつけていません。
標準における、このコマンドを実行するために必要な権限は実装依存の状態です。
