.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TYPE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TYPE \- データ型の削除

.SH SYNOPSIS
.sp
.nf
DROP TYPE \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP TYPE\fR はユーザ定義型を削除します。
データ型を削除できるのは、その所有者のみです。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するデータ型の名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
削除するデータ型に依存するオブジェクト (テーブルの列、関数、演算子など) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このデータ型の削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
\fBbox\fR データ型を削除するには以下のようにします。
.sp
.nf
DROP TYPE box;
.sp
.fi
.SH "互換性"
.PP
このコマンドは標準SQL内の対応するコマンドと似ていますが、\fBCREATE TYPE\fR コマンドと PostgreSQL のデータ型拡張機構は標準 SQL とは異なる点に注意して下さい。
.SH "関連項目"
CREATE TYPE [\fBcreate_type\fR(l)]
