.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_freeplan" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_freeplan \- 以前に保存した計画を解放します。

.SH SYNOPSIS
.sp
.nf
int SPI_freeplan(void *\fIplan\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_freeplan\fRは、以前に\fBSPI_prepare\fRから返された、あるいは、\fBSPI_saveplan\fRで保存されたコマンド実行計画を解放します。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
解放する計画へのポインタ。
.SH "戻り値"
.PP
\fIplan\fRが\fBNULL\fRの場合、\fBSPI_ERROR_ARGUMENT\fRです。
