.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "REVOKE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
REVOKE \- アクセス権限の取り上げ

.SH SYNOPSIS
.sp
.nf
REVOKE [ GRANT OPTION FOR ]
    { { SELECT | INSERT | UPDATE | DELETE | RULE | REFERENCES | TRIGGER }
    [,...] | ALL [ PRIVILEGES ] }
    ON [ TABLE ] \fItablename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { CREATE | TEMPORARY | TEMP } [,...] | ALL [ PRIVILEGES ] }
    ON DATABASE \fIdbname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { EXECUTE | ALL [ PRIVILEGES ] }
    ON FUNCTION \fIfuncname\fR ([\fItype\fR, ...]) [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { USAGE | ALL [ PRIVILEGES ] }
    ON LANGUAGE \fIlangname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { CREATE | USAGE } [,...] | ALL [ PRIVILEGES ] }
    ON SCHEMA \fIschemaname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBREVOKE\fR コマンドは、1つ以上のユーザあるいはユーザグループから以前に与えられた権限を取り上げます。
キーワードPUBLICは暗黙的に定義された全ユーザからなるグループです。
.PP
権限の種類の意味については GRANT [\fBgrant\fR(l)] コマンドの説明を参照してください。
.PP
個々のユーザはすべて、ユーザに直接許可された権限、ユーザが現在属しているグループに許可された権限、そして、PUBLIC に許可された権限を合わせた権限を持っていることに注意して下さい。
従って、例えば、PUBLIC から SELECT 権限を取り上げることは、必ずしもそのオブジェクトに対する SELECT 権限をすべてのユーザが失うことを意味しません。
直接、あるいは、グループ経由で許可されたユーザは、その権限を持ち続けます。
.PP
GRANT OPTION FOR が指定された場合、権限自体ではなく、その権限のgrantオプションのみが取り上げられます。
.PP
ユーザがgrantオプションを持つ権限を保持し、その権限を他ユーザに与えていた場合、他のユーザが保持する権限は依存権限と呼ばれます。
最初のユーザが持つ権限やgrantオプションが取り上げられ、依存権限が存在する場合、CASCADE が指定されると依存権限もまた取り上げられ、指定されていなければ、権限の取り上げが失敗します。
この再帰的な取り上げは、REVOKE を実行したユーザが追跡可能なユーザの連鎖を通して与えられた権限にのみ影響します。
従って、もし、権限が他のユーザを介して与えられたならば、影響を受けるユーザは実際にはその権限を保持する場合もあります。
.SH "注釈"
.PP
既存オブジェクトに付与された権限を表示するには \fBpsql\fR(1)の\fB\\z\fRコマンドを使用してください。
この書式については GRANT [\fBgrant\fR(l)] を参照してください。
.PP
ユーザが直接付与した権限のみをそのユーザは取り上げることができます。
例えば、もし、ユーザ A がgrantオプションを付けてユーザBに権限を与え、その後、ユーザBがユーザCにその権限を与えたとすると、ユーザAはユーザCの権限を直接取り上げることはできません。
その代わり、ユーザAはユーザBからgrantオプションを、CASCADEオプションを付けて取り上げることで、自動的にユーザCに与えられた権限を自動的に取り上げることができます。
.PP
スーパーユーザが\fBGRANT\fR や \fBREVOKE\fR コマンドの発行を選択した場合、そのコマンドは、対象のオブジェクトの所有者によって発行されたかのように動作します。
根本的にすべての権限はオブジェクトの所有者から渡されるもの(グラントオプションの連鎖による間接的な場合もあります)ですので、スーパーユーザは、すべての権限を取り上げることができます。
しかし、これには上述のCASCADE を使用する必要があります。
.SH "例"
.PP
films テーブルから、public に与えた挿入権限を取り上げます。
.sp
.nf
REVOKE INSERT ON films FROM PUBLIC;
.sp
.fi
.PP
kinds ビューから、manuel に与えたすべての権限を取り上げます。
.sp
.nf
  
REVOKE ALL PRIVILEGES ON kinds FROM manuel;
.sp
.fi
.SH "互換性"
.PP
GRANT [\fBgrant\fR(l)] コマンドの互換性についての注釈は、\fBREVOKE\fR にも当てはまります。構文の要約を以下に示します。
.sp
.nf
REVOKE [ GRANT OPTION FOR ] \fIprivileges\fR
    ON \fIobject\fR [ ( \fIcolumn\fR [, ...] ) ]
    FROM { PUBLIC | \fIusername\fR [, ...] }
    { RESTRICT | CASCADE }
.sp
.fi
標準に従うとRESTRICT か CASCADEのどちらかが必要です。
しかし、PostgreSQLではデフォルトでRESTRICTと仮定されます。
.SH "関連項目"
.PP
GRANT [\fBgrant\fR(l)]
