.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE INDEX" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE INDEX \- 新しいインデックスの定義

.SH SYNOPSIS
.sp
.nf
CREATE [ UNIQUE ] INDEX \fIname\fR ON \fItable\fR [ USING \fImethod\fR ]
    ( { \fIcolumn\fR | ( \fIexpression\fR ) } [ \fIopclass\fR ] [, ...] )
    [ WHERE \fIpredicate\fR ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE INDEX\fRは \fIindex_name\fR インデックスを指定されたテーブル上に作ります。
インデックスは主にデータベースの性能を向上させるために使われます。
(しかし不適切な使用は性能の低下につながります。)
.PP
インデックスのキーフィールドは列名として指定されるか、または、括弧内に記載した式として指定されます。
もしインデックスメソッドが複数列に対するインデックスをサポートする場合は、複数のフィールドを指定できます。
.PP
インデックスのフィールドは、テーブル行の1つ以上の列の値から計算される式とすることができます。
この機能は、基本型に何らかの変換を行ったものを元とするデータへの高速なアクセスを行う手段として使用することができます。
例えば、upper(col) 計算に基づくインデックスにより、WHERE upper(col) = 'JIM' 句ではインデックスを使用することができます。
.PP
\fBPostgreSQL\fR は B-tree、R-tree、hash、GiST のインデックスメソッドを用意しています。
B-tree インデックスメソッドは Lehman-Yao 高並行性 B-tree の実装です。
R-tree インデックスメソッドは Guttman の二次分割アルゴリズムを使用する標準 R-tree を実装します。
hash インデックスメソッドは Litwin の線形ハッシュの実装です。
ユーザも独自にインデックスメソッドを定義することができますが、これはかなり複雑です。
.PP
WHERE 句が存在する場合、\fI部分インデックス\fRが作成されます。
部分インデックスは、テーブルの一部、通常は、テーブルの中でより何らかの興味のある部分のみのエントリを持つインデックスです。
例えば、支払済み、未支払の注文を内容としたテーブルがあり、テーブル全体の中で未支払の注文の割合が小さく、かつ、頻繁に使用される場合、この部分のみにインデックスを作成することで性能を向上させることができます。
この他の実現方法としては、\fBUNIQUE\fR 付きの \fBWHERE\fR を使用して、テーブルの一部に一意性を強制することです。
.PP
WHERE 句で使用される式は元となるテーブル内にある列のみを参照することができます(しかし、インデックスされた列だけではなく、全ての列を使用することができます)。 
また、現在、副問い合わせと集約式については、\fBWHERE\fR で使用することができません。
同一の制限は、式で表されたインデックスのフィールドにも適用されます。
.PP
インデックスの定義で使用される全ての関数と演算子は、``不変'' でなければなりません。 
つまり、その結果は入力引数にのみに依存し、(他のテーブルの内容や現時刻などの) 外部からの影響を受けてはなりません。
この制限は、インデックスの動作は十分に定義されたものであることを確実にします。 
ユーザ定義の関数をインデックス式やWHERE句に使用するため、関数を作成する際、その関数に IMMUTABLE (不変) オプションを付けることを忘れないで下さい。
.SH "パラメータ"
.TP
\fBUNIQUE\fR
インデックスが（すでにデータがある状態で）作成される時とデータが追加される時に、テーブル内の値が重複していないかを検査します。
重複エントリを生じる結果となるデータの挿入または更新はエラーとなります。
.TP
\fB\fIname\fB\fR
作成されるインデックスの名前です。 
この名前には、スキーマ名を含めることはできません。
インデックスは、常にその親テーブルと同じスキーマに作成されます。
.TP
\fB\fItable\fB\fR
インデックスが作成されるテーブルの名前です (スキーマ修飾名の場合もあります)。
.TP
\fB\fImethod\fB\fR
インデックスに使われるメソッドの名前です。
btree、hash、rtree、gist から選択します。
デフォルトのメソッドは BTREE です。
.TP
\fB\fIcolumn\fB\fR
テーブルの列の名前です。
.TP
\fB\fIexpression\fB\fR
そのテーブル上の1つ以上の列を使用した式です。
通常この式は、構文で示した通り括弧で括る必要があります。
しかし、式が関数呼び出しという形になっている場合は括弧を省略することができます。
.TP
\fB\fIopclass\fB\fR
演算子クラスの名前です。詳細は下記を参照して下さい。
.TP
\fB\fIpredicate\fB\fR
部分インデックス用制約式です。
.SH "注釈"
.PP
インデックスが、いつ使用されるか、いつ使用されないか、どのような場合に有用かといった情報については[XRef to INDEXES] を参照してください。
.PP
現在では、B-treeとGiSTアクセスメソッドのみが、複数列に対するインデックスをサポートしています。
32個まではデフォルトで指定することができます（この制限はPostgreSQL構築の際に変更できます）。
現在ではB-treeのみが一意性インデックスをサポートしています。
.PP
\fI演算子クラス\fRはインデックスのそれぞれの列に指定することができます。
演算子クラスはその列のインデックスによって使われる演算子を識別します。
たとえば、4バイト整数上のB-treeインデックスはint4_opsクラスを使います。 
この演算子クラスは4バイト整数の比較関数を含みます。
実践では、通常、列のデータ型のデフォルト演算子クラスは十分です。
演算子クラスを持つ大きな意味は、いくつかのデータ型には1つ以上の意味がある順番があるかもしれないということです。
たとえば、絶対値または実数部のどちらかを使って複素数のデータ型をソートしたいかもしれません。
そうするためには2つの演算子クラスをそのデータ型に定義し、インデックスを作る時に適切なクラスを選択します。
演算子クラスについての詳細は、[XRef to INDEXES-OPCLASS] と [XRef to XINDEX] を参照してください。
.PP
インデックスを削除するには DROP INDEX [\fBdrop_index\fR(l)]を使用して下さい。
.SH "例"
.PP
テーブル films の title 列に B-tree インデックスを作ります。
.sp
.nf
CREATE UNIQUE INDEX title_idx ON films (title);
.sp
.fi
.SH "互換性"
.PP
\fBCREATE INDEX\fR は PostgreSQL の言語拡張です。
標準SQLにはインデックスについての規定はありません。
