.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP DOMAIN" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP DOMAIN \- ドメインの削除

.SH SYNOPSIS
.sp
.nf
DROP DOMAIN \fIname\fR [, ...]  [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP DOMAIN\fRはドメインを削除します。
ドメインの所有者のみがそのドメインを削除することができます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存のドメインの名前です。(スキーマ修飾名でも可)
.TP
\fBCASCADE\fR
ドメインに依存するオブジェクト (テーブルの列など) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、そのドメインの削除要求を拒否します。これがデフォルトです。
.SH "例"
.PP
\fBbox\fR ドメインを削除します。
.sp
.nf
DROP DOMAIN box;
.sp
.fi
.SH "互換性"
.PP
このコマンドは標準SQLに従っています。
.SH "関連項目"
CREATE DOMAIN [\fBcreate_domain\fR(l)]
