.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP DATABASE" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP DATABASE \- データベースの削除

.SH SYNOPSIS
.sp
.nf
DROP DATABASE \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP DATABASE\fRは、データベースを削除します。
そのデータベースの項目をカタログから削除し、データを保存していたディレクトリの削除を行ないます。
データベースの所有者のみがこのコマンドを実行することができます。
また、実行ユーザや他のユーザが対象とするデータベースに接続している時には実行できません。
(このコマンドを発行するには、template1 や他のデータベースに接続してください。)
.PP
\fBDROP DATABASE\fR は元に戻すことができません。注意して使用して下さい。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するデータベースの名前です。
.SH "注釈"
.PP
\fBDROP DATABASE\fR はトランザクションブロックの内部では実行できません。
.PP
対象とするデータベースに接続している場合、このコマンドを実行することができません。
したがって、このコマンドのラッパである dropdb [\fBdropdb\fR(1)]プログラムを使用する方が便利かもしれません。
.SH "互換性"
.PP
標準SQLには\fBDROP DATABASE\fR文はありません。
.SH "関連項目"
CREATE DATABASE [\fBcreate_database\fR(l)]
