.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "RESET" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
RESET \- 実行時パラメータの値をデフォルト値に戻す

.SH SYNOPSIS
.sp
.nf
RESET \fIname\fR
RESET ALL
.sp
.fi
.SH "説明"
.PP
\fBRESET\fR は実行時パラメータをデフォルト値に戻します。
\fBRESET\fR は下記のように記述することもできます。
.sp
.nf
SET \fIparameter\fR TO DEFAULT
.sp
.fi
詳細は SET [\fBset\fR(l)]を参照してください。
.PP
デフォルト値は、現行セッション内で \fBSET\fR コマンドが発行されない場合に変数が持っていた値として定義されます。
この値の実際の出所は、コンパイル済みのデフォルトか、設定ファイル、コマンドラインオプション、あるいは、データベース毎ユーザ毎のデフォルト設定のどれかとなります。
詳細は [XRef to RUNTIME-CONFIG] を参照してください。
.PP
\fBRESET\fRのトランザクションでの振る舞いの詳細は、\fBSET\fR マニュアルページを参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
実行時パラメータの名前です。
一覧についてはSET [\fBset\fR(l)] を参照してください。
.TP
\fBALL\fR
設定可能なすべての実行時パラメータをデフォルト値に戻します。
.SH "例"
.PP
DATESTYLE をデフォルト値に設定します。
.sp
.nf
RESET datestyle;
.sp
.fi
.PP
GEQO をデフォルト値に設定します。
.sp
.nf
RESET geqo;
.sp
.fi
.SH "互換性"
.PP
\fBRESET\fR は PostgreSQLの拡張です。
