.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_CONNECT" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_connect \- サーバとの接続を開きます。

.SH SYNOPSIS
.sp
.nf
pg_connect -conninfo \fIconnectOptions\fR
pg_connect \fIdbName\fR [-host \fIhostName\fR] [-port \fIportNumber\fR] [-tty \fItty\fR] [-options \fIserverOptions\fR]
.sp
.fi
.SH "説明"
.PP
\fBpg_connect\fRはPostgreSQLサーバとの接続を開きます。
.PP
2つの構文を使用できます。
\fBpg_connect\fRの古い構文では、設定可能なオプションはそれぞれ別々のオプションスイッチを持ちます。
新しい形式では、複数のオプション値を持つことができる、単一のオプション文字が提供されています。
\fBpg_conndefaults\fRを使用して、新しい構文で使用可能なオプションの情報を取り出すことができます。
.SH "引数"
"新様式"
.TP
\fB\fIconnectOptions\fB\fR
keyword = valueという書式でそれぞれを記述した、接続オプション文字列です。
有効なオプションの一覧は\fBPQconnectdb\fR\fBlibpq\fR関数の説明部分に記載されています。
.PP
"旧様式"
.TP
\fB\fIdbName\fB\fR
接続するデータベースの名前です。
.TP
\fB-host \fIhostName\fB\fR
接続するデータベースサーバのホスト名です。
.TP
\fB-port \fIportNumber\fB\fR
接続するデータベースサーバのTCPポート番号です。
.TP
\fB-tty \fItty\fB\fR
省略可能な、サーバからのデバッグ出力用のファイルもしくはTTYです。
.TP
\fB-options \fIserverOptions\fB\fR
サーバに渡す、追加設定オプションです。
.SH "戻り値"
.PP
成功時、データベース接続用ハンドルが返されます。
ハンドルは、pgsqlという接頭詞で始まります。
