.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "END" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
END \- 現在のトランザクションのコミット

.SH SYNOPSIS
.sp
.nf
END [ WORK | TRANSACTION ]
.sp
.fi
.SH "説明"
.PP
\fBEND\fR は現在のトランザクションをコミットします。
そのトランザクションでなされた変更は全て、他から可視となり、クラッシュが起きたとしても信頼性が保証されます。
このコマンドは、PostgreSQLの拡張で、COMMIT [\fBcommit\fR(l)]と同一です。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。
何も効果がありません。
.SH "注釈"
.PP
トランザクションのアボートには ROLLBACK [\fBrollback\fR(l)]を使用してください。
.PP
トランザクションの外側で \fBEND\fR を発行しても害はありませんが、警告メッセージが表示されます。
.SH "例"
.PP
現在のトランザクションをコミットし、全ての変更を永続化します。
.sp
.nf
END;
.sp
.fi
.SH "互換性"
.PP
\fBEND\fRはPostgreSQL の拡張であり、これは、標準SQLで規定された [XRef to SQL-COMMIT-TITLE]と機能的に同じものです。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)]
