.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_copytuple" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
SPI_copytuple \- 上位エグゼキュータ内に行のコピーを作成します。

.SH SYNOPSIS
.sp
.nf
HeapTuple SPI_copytuple(HeapTuple \fIrow\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_copytuple\fRは上位エグゼキュータコンテキスト内に行のコピーを作成します。
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
コピーされる行。
.SH "戻り値"
.PP
コピーされた行。
\fItuple\fR が \fBNULL\fRの場合のみ\fBNULL\fRです。
