.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_OPEN" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_open \- ラージオブジェクトを開きます。

.SH SYNOPSIS
.sp
.nf
pg_lo_open \fIconn\fR \fIloid\fR \fImode\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_open\fRはラージオブジェクトを開きます。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIloid\fB\fR
ラージオブジェクトのOIDです。
.TP
\fB\fImode\fB\fR
ラージオブジェクトのアクセスモードを指定します。
モードとしてr、w、もしくはrwをとることができます。
.SH "戻り値"
.PP
その後のラージオブジェクトコマンドで使用する記述子です。
