.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP USER" "" "2004-06-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP USER \- データベースユーザアカウントの削除

.SH SYNOPSIS
.sp
.nf
DROP USER \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP USER\fR は指定されたユーザを削除します。
そのユーザが所有するテーブル、ビュー、その他のオブジェクトは削除しません。 
ユーザがデータベースを所有している場合は、エラーが出されます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するユーザ名です。
.SH "注釈"
.PP
PostgreSQL には、このコマンドと同じ機能を持つ (実際は、このコマンドを呼び出しています) プログラム dropuser [\fBdropuser\fR(1)] があり、コマンドシェルから実行することができます。
.PP
データベースを所有するユーザを削除するには、まず、データベースを削除するかその所有者を変更してください。
.SH "例"
.PP
ユーザアカウントを削除します。
.sp
.nf
DROP USER jonathan;
.sp
.fi
.SH "互換性"
.PP
\fBDROP USER\fR 文は PostgreSQL の拡張です。 
標準SQLでは、ユーザの定義は実装に任されています。
.SH "関連項目"
ALTER USER [\fBalter_user\fR(l)], CREATE USER [\fBcreate_user\fR(l)]
