.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "PG_LO_LSEEK" "" "2004-06-19" "" "PostgreSQL 7.4.5 文書"
.SH NAME
pg_lo_lseek \- ラージオブジェクトの位置をシークします。

.SH SYNOPSIS
.sp
.nf
pg_lo_lseek \fIconn\fR \fIdescriptor\fR \fIoffset\fR \fIwhence\fR
.sp
.fi
.SH "説明"
.PP
\fBpg_lo_lseek\fRは、現在の読みとり/書き込み位置を\fIwhence\fRで指定した位置から\fIoffset\fRバイト移動します。
.SH "引数"
.TP
\fB\fIconn\fB\fR
ラージオブジェクトが存在するデータベースへの接続用ハンドルです。
.TP
\fB\fIdescriptor\fB\fR
\fBpg_lo_open\fRによるラージオブジェクト用の記述子です。
.TP
\fB\fIoffset\fB\fR
バイト単位の新しいシーク位置です。
.TP
\fB\fIwhence\fB\fR
どこから新しいシーク位置を計算するのかを指定します。
SEEK_CUR (現在位置から)、
SEEK_END (末尾から)、またはSEEK_SET (先頭から)。
.SH "戻り値"
.PP
ありません。
